#========================================================================================
# package      DE_EPAGES::Amazon::API::Attributes::AmazonConfig
# state        private
# base         DE_EPAGES::Object::API::BaseAttribute
# description  Attribute interface AmazonConfig for class AmazonConfig.
#========================================================================================
package DE_EPAGES::Amazon::API::Attributes::AmazonConfig;
use DE_EPAGES::Core::API::PerlTools qw ( isValid );

use base DE_EPAGES::Object::API::BaseAttribute;

use strict;

#========================================================================================
# function     getAttributes
# state        private
#----------------------------------------------------------------------------------------
# syntax       $hValues = $Package->( $Object, $aNames );
# example      # never call getAttributes directly!
#               $Value = $Object->get( $AttributeName );
#----------------------------------------------------------------------------------------
# description  Returns attribute values of an object.
#               Used by <function DE_EPAGES::Object::Object::Object::get>
#----------------------------------------------------------------------------------------
# input        $Object | object | object
# input        $aNames | list of attribute names | ref.array
# return       $hValues | attribute name => value hash | ref.hash
#========================================================================================
sub getAttributes {
    shift;
    my ( $Object, $aNames ) = @_;

    my %Info;
    foreach my $Name (@$aNames) {
        if ( $Name eq 'HistoryName' ) {
            $Info{$Name} = $Object->get('PortalSite')->get('SiteName');
        }
        elsif ( $Name eq 'AmazonTransactions' ) {
            $Info{$Name} = $Object->folder('AmazonTransactions')->children;
        }
        elsif ( $Name eq 'IsSettingsComplete' ) {
            $Info{$Name} = (
                isValid($Object->get('MWSMerchantID')) && isValid($Object->get('SPAPI_AccessToken'))
            ) ? 1 : 0;
        }
        elsif ( $Name eq 'UseSPAPIAccount' ) {
            $Info{$Name} = isValid( $Object->get('MWSMerchantID') ) || !$Object->get('MerchantLogin');
        }
        elsif ( $Name eq 'DefaultsPriceAdaption' ) {
            my $DefaultsPriceAdaptionSelect = $Object->get('DefaultsPriceAdaptionSelect');
            $Info{$Name} = (defined $DefaultsPriceAdaptionSelect && $DefaultsPriceAdaptionSelect != -1) ? 1 : 0;
        }
        elsif ( $Name eq 'DefaultsPriceAdaptionIsAbsolute' ) {
            my $DefaultsPriceAdaptionSelect = $Object->get('DefaultsPriceAdaptionSelect');
            if (!defined $DefaultsPriceAdaptionSelect || $DefaultsPriceAdaptionSelect == -1) {
                $Info{$Name} = undef;
            } else {
                $Info{$Name} = $DefaultsPriceAdaptionSelect;
            }
        }
    }
    return \%Info;
}

1;
