#========================================================================================
# package      DE_EPAGES::Catalog::API::Resource::CategoriesProductsMapResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for a mapping categories <-> products
#========================================================================================
package DE_EPAGES::Catalog::API::Resource::CategoriesProductsMapResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectCollectionResource;

use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Catalog::API::CategoryService;
use JSON;

use strict;



sub service {
    return LoadObjectByPath('/RestServices/CategoriesProductsMap');
}



sub class {
    return 'Shop';
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        POST => [
            ['post', 'application/x-www-form-urlencoded'],
        ],
        DELETE => [
            ['delete', 'application/json'],
            ['delete', 'application/vnd.epages.v1+json'],
        ]
    }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/products-categories/?$|;
    return 1;
}



sub requestContext {
    my $self = shift;
    my ( $Site, $GUID, $Request ) = @_;

    return $self->SUPER::requestContext( $Site, $GUID, $Request );
}



sub params {
    my $self = shift;
    my ( $ActionName, $Object, $Request ) = @_;

    if ($ActionName eq 'post') {
        return [ $Object ];
    } elsif ($ActionName eq 'delete') {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $Categories = $hQuery->{'categoryId'};
        my $Products = $hQuery->{'productId'};
        return [ $Object, $Categories, $Products ];
    } else {
        return [ $Object ];
    }
}



sub post {
    my $self = shift;
    my ( $Shop, $hRequestBody ) = @_;

    my $Categories = $hRequestBody->{'categoryId'};
    if(ref($Categories)ne 'ARRAY'){
        $Categories = [$hRequestBody->{'categoryId'}];
    }

    my $Products = $hRequestBody->{'productId'};
    if(ref($Products)ne 'ARRAY'){
        $Products = [$hRequestBody->{'productId'}];
    }

    my $CategoryService = $self->_createCategoryService();
    return $CategoryService->createCategoriesProductsMap($Shop, $Categories, $Products);

}



sub delete {
    my $self = shift;
    my ( $Shop, $Categories, $Products ) = @_;

    my $CategoryService = $self->_createCategoryService();
    return $CategoryService->removeCategoriesProductsMap($Shop, $Categories, $Products);

}



sub _createCategoryService {
    my $self = shift;
    return DE_EPAGES::Catalog::API::CategoryService->new();
}



1;
