use strict;
use Getopt::Long;
use DE_EPAGES::Core::API::PerlTools qw ( isValid );
use DE_EPAGES::Core::API::File qw ( WriteFile CorrectPathSlashes );
use XML::LibXSLT;
use XML::LibXML;

# parameter process

my (
    $TARGET_DIR,
    $CARTRIDGE_NAME,
    $COMPANY_NAME
);
GetOptions(

    'targetdir=s'       => \$TARGET_DIR,
    'cartridge=s'       => \$CARTRIDGE_NAME,
    'company=s'         => \$COMPANY_NAME
);

usage('targetdir')  unless isValid($TARGET_DIR);

#usefull to create the path for the targetfile
my $Company = 'DE_EPAGES';
if(isValid($COMPANY_NAME)){
    $Company = $COMPANY_NAME;
}
my $TargetDir = $TARGET_DIR;
my @SOURCE_FILE = @ARGV;

Main();

sub usage {
    my ( $FalseParameter) = @_;
    print STDERR (
     "error: parameter ($FalseParameter) is not correct.\n"
    ."usage: perl $0 [options] sourcefile ... \n"
    ."options:\n"
    ."\t-targetdir          target directory                            ($TARGET_DIR)\n"
    ."\t-cartridge          name of cartridge   (optional)              ($CARTRIDGE_NAME)\n"
    ."\t-company            name of company   (optional)                ($COMPANY_NAME)\n"
    );
    exit 1;
}

sub Main{

    transformProfile();
    transformModel($_) foreach @SOURCE_FILE;
}

sub createTargetPath{
    my ($SourceModel) = @_;

    my @SubStrings = split(/\\|\//,$SourceModel);
    my $ArrayLength = @SubStrings;
    my ($ModelName) = split(/\./,$SubStrings[$ArrayLength-1]);

    if(not -d "$TARGET_DIR"){
        mkdir("$TARGET_DIR");
    }
    $TargetDir = $TARGET_DIR.'\/'.$Company;
    if(not -d "$TargetDir"){
        mkdir("$TargetDir");
    }
    if(isValid($CARTRIDGE_NAME)){
        $TargetDir.='\/'.$CARTRIDGE_NAME;
        if(not -d "$TargetDir"){
            mkdir("$TargetDir");
        }
    }
    $TargetDir.='\/Models';
    if(not -d "$TargetDir"){
        mkdir("$TargetDir");
    }
    $TargetDir.='\/'.$ModelName.'.xml';
}

sub transformProfile{
    #transform the ePages-Profile, with datatypes and stereotypes, in an XML-file which is ordered by their ID's
    my $xslt = XML::LibXSLT->new();

    my $CG = "$ENV{'EPAGES_CARTRIDGES'}/DE_EPAGES/CodeGenerator";
    my $source = XML::LibXML->load_xml(location => "$CG/Models/EPAGES.xmi");
    my $style_doc = XML::LibXML->load_xml(location=>"$CG/Templates/epages/XSLT/transformProfile.xsl", no_cdata=>1);

    my $stylesheet = $xslt->parse_stylesheet($style_doc);

    my $results = $stylesheet->transform($source);
    print $stylesheet->output_file($results, "$CG/Templates/epages/XSLT/orderedProfile.xml");

}

sub transformModel{
    my ($SourceModel) = @_;

    createTargetPath($SourceModel);
    $TargetDir =~ s/\\//g;

    #transform the XMI-file in our interface-XML-model
    my $xslt = XML::LibXSLT->new();

    my $CG = "$ENV{'EPAGES_CARTRIDGES'}/DE_EPAGES/CodeGenerator";
    my $source = XML::LibXML->load_xml(location => "$SourceModel");
    my $style_doc = XML::LibXML->load_xml(location=>"$CG/Templates/epages/XSLT/transformModel.xsl", no_cdata=>1);

    my $stylesheet = $xslt->parse_stylesheet($style_doc);

    my $results = $stylesheet->transform($source);

    # Bug in XSLT-lib preventing the output through $stylesheet->output_file on linux
    my $Model = $stylesheet->output_string($results);
    WriteFile(CorrectPathSlashes($TargetDir), \$Model, {'create_directory' => 1});
}
