#========================================================================================
# package      DE_EPAGES::Content::API::Resource::LegalInformationBaseResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements common methods for all legal page resources.
#========================================================================================
package DE_EPAGES::Content::API::Resource::LegalInformationBaseResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Object::API::Object::Locale;
use JSON qw ( decode_json );

use strict;

## no critic (ProhibitUnusedPrivateSubroutines)



sub class {
    return 'Shop';
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
             ['get', 'application/vnd.epages.v1+json'],
             ['get', 'application/json'],
         ],
        PUT => [
             ['put', 'application/vnd.epages.v1+json'],
             ['put', 'application/json'],
         ],
    }->{$RequestMethod};
}



sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if ($ActionName eq 'get') {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        return [ $Object, $LocaleID ];
    }
    elsif ($ActionName eq 'put') {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        return [ $Object, decode_json($Request->decoded_content()), $LocaleID ];
    }
    else {
        return [ $Object ];
    }
}



sub _getLanguageID {
    my $self = shift;
    my ($Shop, $LocaleID) = @_;

    my $Context = DE_EPAGES::Shop::API::Resource::ShopRequestContext->new($Shop);
    $LocaleID = $Context->validLocale($LocaleID);
    my $Locale = DE_EPAGES::Object::API::Object::Locale->load($LocaleID);

    return $Locale->get('LanguageID');
}

1;
