#========================================================================================
# package      DE_EPAGES::Content::API::Resource::LegalInformationSummaryResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  Resource for legal information summary.
#========================================================================================
package DE_EPAGES::Content::API::Resource::LegalInformationSummaryResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Object::API::Object::Locale;
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::Content::API::Legal::LegalInformationSummary;

use strict;



sub class {
    return 'Shop';
}



sub service {
    return LoadObjectByPath('/RestServices/LegalInformationSummary');
}



sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/legal/?$|;
    return 1;
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
             ['get', 'application/vnd.epages.v1+json'],
             ['get', 'application/json'],
         ],
    }->{$RequestMethod};
}



sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if ($ActionName eq 'get') {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        return [ $Object, $LocaleID ];
    }
    else {
        return [ $Object ];
    }
}



sub get {
    my $self = shift;
    my ($Shop, $LocaleID) = @_;

    my $LanguageID = $self->_getLanguageID($Shop, $LocaleID);

    my $LegalInformationSummary = DE_EPAGES::Content::API::Legal::LegalInformationSummary->new($Shop);
    my $hLegalInformationSummaryData = $LegalInformationSummary->get($LanguageID);

    return $hLegalInformationSummaryData;
}



sub _getLanguageID {
    my $self = shift;
    my ($Shop, $LocaleID) = @_;

    my $Context = DE_EPAGES::Shop::API::Resource::ShopRequestContext->new($Shop);
    $LocaleID = $Context->validLocale($LocaleID);
    my $Locale = DE_EPAGES::Object::API::Object::Locale->load($LocaleID);

    return $Locale->get('LanguageID');
}

1;
