use strict;

use Getopt::Long;
use File::Temp qw(tempfile);

use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::File qw( MergeIniFiles CopyFile DeleteFile GetFileContent );

sub Main {

    local $| = 1;
    my %Options = ();
    my @GetOpt = qw(file=s inplace help);

    usage() unless GetOptions(\%Options, @GetOpt);
    usage() if $Options{help};
    usage() unless $Options{file};
    usage("No such file: $Options{file}") unless -f $Options{file};

    my $Output = $Options{file};
    if (not $Options{inplace}) {
        (undef, $Output) = tempfile();
        CopyFile($Options{file}, $Output);
    }

    MergeIniFiles($Output, '/dev/null', undef,
                  { 'FirstSections' => [qw(LOOPS EXAMPLE)] });

    if (not $Options{inplace}) {
        my $rContent = GetFileContent($Output);
        print $$rContent, "\n";
        DeleteFile($Output);
    }

}

sub usage {
    my ($ErrorMsg) = @_;
    print STDERR "Error:\n    $ErrorMsg\n" if $ErrorMsg;
    print STDERR <<END_USAGE;
Description:
    Sorts Scheduler.conf and writes the result to standard output.

Usage:
    perl $0 -file Scheduler.conf [-inplace] [-help]

Options:
    -file:     Scheduler.conf to sort
    -inplace:  the result is written into Scheduler.conf and not to standard output

Flags:
    -help          show the command line options
END_USAGE
    exit 2;
}

RunScript(
    'Sub' => \&Main
);

1;
