use strict;
use Test::More tests => 11;
use DE_EPAGES::Core::API::Script qw( RunScript );

sub Main {

    ok( 1, 'init');

    my $Date = '2022-07-27T07:00';
    my $Expected = $Date. ':00';
    my ($dt, $Found, $Strptime);
    foreach my $Suffix  ('', ':00', ':00.000', ':00.000Z') {
        $dt = DateTime::Format::ISO8601->new()->parse_datetime($Date.$Suffix);
        $dt->set_time_zone('UTC');
        $Found = $dt->datetime();
        is($Found, $Expected, "ISO8601->parse_datetime('$Date$Suffix') -> $Found");
    }

    $Date = '2010-01-13T15:19:14-04:00';
    $dt = DateTime::Format::ISO8601->new()->parse_datetime($Date);
    $Found = $dt->ymd;
    is($Found, '2010-01-13', "ISO8601->parse_datetime('$Date') -> $Found");
    $Found = $dt->hms;
    is($Found, '15:19:14', "ISO8601->parse_datetime('$Date') -> $Found");
    $Found = $dt->time_zone->name;
    is($Found, '-0400', "ISO8601->parse_datetime('$Date') -> $Found");


    my %DatePattern = ( '2010-01-13T15:19:14Z' => '%Y-%m-%dT%H:%M:%SZ',
                        '01/13/2010' => '%m/%d/%Y',
                        '2010-01-13' => '%Y-%m-%d', );
    foreach my $Date (keys %DatePattern) {
        $Strptime = DateTime::Format::Strptime->new( pattern => $DatePattern{$Date} );
        $dt = $Strptime->parse_datetime($Date);
        $Found = $dt->ymd;
        is($Found, '2010-01-13', "Strptime->parse_datetime('$Date') -> $Found");
    }
}

RunScript(Sub=>\&Main, Debug=>1);
