use strict;
use Test::Simple tests => 493;
use DE_EPAGES::Core::API::Error qw( ExistsError );
use DE_EPAGES::Core::API::PerlTools qw( GetCurrentDateTime );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::Object::DateTimeFormatter;

sub Main {

    ok( 1, 'init');

    my $Now = GetCurrentDateTime();
    my @SupportedLocales = qw(
        ca_ES
        cs_CZ
        da_DK
        de_AT de_BE de_CH de_DE de_LU
        en_AU en_CA en_CH en_DK en_GB en_IE en_NZ en_US
        es_AR es_BO es_CO es_EC es_ES es_MX es_US
        fi_FI
        fr_BE fr_CA fr_CH fr_FR fr_LU
        it_CH it_IT
        nb_NO no_NO
        nl_BE nl_NL
        pt_BR pt_PT
        ru_RU ru_UA
        sv_FI sv_SE
        );
    foreach my $LocaleID (@SupportedLocales) {
        my $Formatter = DE_EPAGES::Core::API::Object::DateTimeFormatter->new('locale'=> $LocaleID);
        foreach my $DateType (qw (date time datetime)) {
            foreach my $Length (qw (short medium long full )) {
                my ($FormattedValue, $NowDec, $DecFormattedValue);
                eval {
                    $FormattedValue = $Formatter->format_datetime($Now, $DateType, $Length);
                    $NowDec = $Formatter->parse_datetime($FormattedValue, $DateType, $Length);
                    $DecFormattedValue = $Formatter->format_datetime($NowDec, $DateType, $Length);

                    if ($DateType eq 'date' and $Length eq 'medium') {
                        # <DateTime::Format::Strptime::VERSION = '1.54'>
                        # When abbreviating, sometimes there's a period, sometimes not.
                        # $month =~ s/\.$//;
                        # </>
                        $FormattedValue =~ s,^([0-9]+\s+\S+)\.(\s+.*),$1$2,;
                        $DecFormattedValue =~ s,^([0-9]+\s+\S+)\.(\s+.*),$1$2,;
                    }


                    my $Test = $FormattedValue eq $DecFormattedValue ? 1 : 0;
                    ok ($Test, sprintf ('%s:%s:%s=%s (%s=%s)', $LocaleID, $DateType, $Length,
                                        $Formatter->formatString($DateType, $Length),
                                        $FormattedValue, $DecFormattedValue));
                };
                if (ExistsError()) {
                    ok (0, sprintf ('%s:%s:%s=%s (%s!=%s)', $LocaleID, $DateType, $Length,
                                    $Formatter->formatString($DateType, $Length),
                                    $FormattedValue, $DecFormattedValue));
                }
            }
        }
    }
}

RunScript(Sub=>\&Main, Debug=>1);
