#========================================================================================
# package      DE_EPAGES::Customer::API::Resource::CustomerCollectionAndCreationResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for listing and creating customer.
#========================================================================================
package DE_EPAGES::Customer::API::Resource::CustomerCollectionAndCreationResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath LoadClassByAlias );
use DE_EPAGES::Object::API::Object::Locale;
use DE_EPAGES::Shop::API::Resource::Formatter;
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::WebService::API::ResourcePager;

use strict;



sub service {
    return LoadObjectByPath('/RestServices/CustomerCollectionAndCreation');
}



sub class {
    return 'Shop';
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
        POST => [
            ['post', 'application/vnd.epages.v1+json'],
            ['post', 'application/json'],
        ],
    }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/customers/?$|;
    return 1;
}



sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if ( $ActionName eq 'get' ) {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $ResultsPerPage = $hQuery->{'resultsPerPage'}->[0];
        my $Page = $hQuery->{'page'}->[0];
        return [ $Object, $ResultsPerPage, $Page ];
    }
    else {
        return [$Object];
    }
}



sub get {
    my $self = shift;
    my ($Shop, $ResultsPerPage, $Page) = @_;

    my $hPageOptions = {
        'Page' => $Page,
        'PageSize' => $ResultsPerPage,
    };
    my $Pager = $self->_createResourcePager($hPageOptions);

    my $CustomerService = $self->_createCustomerService();
    my $aCustomerIDs = LoadClassByAlias('Customer')->findObjects('ByShopID', [ $Shop->id ]);

    return $Pager->pagedItems($aCustomerIDs, sub {
        my $CustomerID = $_;
        my $Customer = $Shop->loadObject($CustomerID, 'Customer');
        $CustomerService->getCustomerData($Customer);
    });
}



sub post {
    my $self = shift;
    my ($Shop, $hRequestBody) = @_;

    my $CustomerService = $self->_createCustomerService();

    return $CustomerService->createCustomer($Shop, $hRequestBody);
}



sub _createCustomerService {
    return DE_EPAGES::Customer::API::CustomerService->new();
}

sub _createResourcePager {
    my $self = shift;
    my ($hPageOptions) = @_;
    return DE_EPAGES::WebService::API::ResourcePager->new($hPageOptions);
}

1;
