#========================================================================================
# package      DE_EPAGES::Customer::API::Resource::CustomerResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for a single customer.
#========================================================================================
package DE_EPAGES::Customer::API::Resource::CustomerResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::Customer::API::CustomerService;

use strict;

sub service {
    return LoadObjectByPath('/RestServices/Customer');
}

sub class {
    return 'Customer';
}

sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
        PATCH => [
            ['patch', 'application/vnd.epages.v1+json'],
            ['patch', 'application/json'],
        ]
    }->{$RequestMethod};
}

sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/customers/([^/]+)/?$|;

    return $1;
}

sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    return [$Object];
}

sub get {
    my $self = shift;
    my ($Customer) = @_;

    my $CustomerService = $self->_createCustomerService();
    my $hCustomerData = $CustomerService->getCustomerData($Customer);

    return $hCustomerData;
}

sub patch {
    my $self = shift;
    my ($Customer, $ahRequestBody) = @_;

    my $CustomerService = $self->_createCustomerService();
    $CustomerService->updateCustomerPartially($Customer, $ahRequestBody);

    return $self->get($Customer);
}

sub _createCustomerService {
    return DE_EPAGES::Customer::API::CustomerService->new();
}

1;
