﻿#========================================================================================
# §package      DE_EPAGES::Design::API::Attributes::Style_Ext
# §state        private
# §base         DE_EPAGES::Object::API::BaseAttribute
# §description  Attribute interface for Style.
#========================================================================================
package DE_EPAGES::Design::API::Attributes::Style_Ext;
use base qw( DE_EPAGES::Object::API::BaseAttribute );

use strict;
use utf8;

use DE_EPAGES::Object::API::Factory qw( LoadRootObject LoadClassByAlias );
use DE_EPAGES::Shop::API::Feature qw( LoadFeatureByAlias );

##no critic qw(ProhibitCascadingIfElse)

sub getAttributes {
    my $self = shift;
    my ($Style, $aNames) = @_;
    my %Values;

    foreach my $Name (@$aNames) {
        if ($Name eq 'UserDefinedNavBarElementCount') {
            my $Class           = LoadClassByAlias('NavBarElement');
            my $aNavBarElements = $Class->getObjects('ByStyleID', [$Style->id]);
            my $FeatureID       = LoadFeatureByAlias('UserDefinedNavBarElements')->id;
            my $Count           = 0;

            foreach my $NavBarElement (@$aNavBarElements) {
                my $NavElementFeature = $NavBarElement->get('NavElement')->get('Feature');
                next unless defined $NavElementFeature;
                $Count++ if $NavElementFeature->id == $FeatureID;
            }

            $Values{$Name} = $Count;
        }
        elsif ($Name eq 'VisibleNavBars') {
            $Values{$Name} = [grep { $Style->get($_->alias . 'IsVisible') } @{LoadRootObject->get('NavBars')}];
        }
        elsif ($Name eq 'UsedElements') {
            # initialize hash with NavElement classes
            my $aAllNavElements = LoadRootObject()->child('NavElements')->children;
            my %UsedElements = map { $_->alias => 0 } @$aAllNavElements;

            # increment usage counter by NavBarElements
            if ($Style->existsChild('NavBarElements')) {
                my $aAllNavBarElements = $Style->child('NavBarElements')->children;
                $UsedElements{$_->get('NavElement')->alias}++ foreach @$aAllNavBarElements;
            }

            # example: #UsedElements.TextElement shows the number of text elements in the style
            $Values{$Name} = \%UsedElements;
        }
        elsif ($Name eq 'ScaleLogoSize') {
            my $Size = 90;    ## no critic qw( ProhibitMagicNumbers )
            my ($Logo) = $Style->existsChild('NavBarElements')
                ? grep { $_->class->alias eq 'Logo' } @{$Style->child('NavBarElements')->children}
                : (undef);

            if (defined $Logo) {
                if ($Style->class->existsAttribute($Logo->get('NavBar')->alias . 'NavBarHeight')) {
                    $Size = _RemovePx($Style->get($Logo->get('NavBar')->alias . 'NavBarHeight'));
                }
                else {
                    $Size = -1 * (_RemovePx($Style->get($Logo->get('NavBar')->alias . 'NavBarWidth'))
                                  - _RemovePx($Style->get($Logo->get('NavBar')->alias . 'PaddingLeft'))
                                  - _RemovePx($Style->get($Logo->get('NavBar')->alias . 'PaddingRight')));
                }
            }

            $Values{$Name} = $Size;
        }
        elsif ($Name eq 'URL') {
            $Values{$Name} = $Style->buildCSSWebPath('StorefrontStyle');
        }
        elsif ($Name eq 'EditorURL') {
            $Values{$Name} = $Style->buildCSSWebPath('EditorStyle');
        }
        elsif ($Name eq 'StyleExtensionCSS') {
            if ($Style->get('IsImportedWithoutTemplate')) {
                if (defined LoadRootObject()->get('StaticResourceURL')) {
                    $Values{$Name} = $Style->get('PublicPath') . '/StyleExtension.css';
                } else {
                    $Values{$Name} = $Style->get('WebPath') . '/StyleExtension.css';
                }
            }
            else {
                my $StyleTemplate = $Style->get('StyleTemplate');
                $Values{$Name} = $StyleTemplate ? $StyleTemplate->get('StyleExtensionCSS') : undef;
            }
        }
        elsif ($Name eq 'StyleExtensionJS') {
            if ($Style->get('IsImportedWithoutTemplate')) {
                my $StyleExtensionJSPublicPath = $Style->get('PublicPath') . '/StyleExtension.js';
                my $StyleExtensionJSWebPath = $Style->get('WebPath') . '/StyleExtension.js';
                $Values{$Name} = (-e $StyleExtensionJSPublicPath) ? $StyleExtensionJSWebPath : undef;
            }
            else {
                my $StyleTemplate = $Style->get('StyleTemplate');
                $Values{$Name} = $StyleTemplate ? $StyleTemplate->get('StyleExtensionJS') : undef;
            }
        }
        elsif ($Name eq 'StyleExtensionMinJS') {
            my $StyleExtensionMinJSPublicPath = $Style->get('PublicPath') . '/StyleExtension.min.js';
            my $StyleExtensionMinJSWebPath = $Style->get('WebPath') . '/StyleExtension.min.js';
            $Values{$Name} = (-e $StyleExtensionMinJSPublicPath) ? $StyleExtensionMinJSWebPath : $Style->get('StyleExtensionJS');
        }
        else {
            die "Unknown attribute $Name";
        }
    }

    return \%Values;
}

sub _RemovePx {
    my ($Value) = @_;
    $Value =~ s/px$//i;
    return $Value;
}

1;
