use strict;
use Getopt::Long;
use Time::HiRes qw (time);
use DE_EPAGES::Cartridge::API::Table::Cartridge qw ( ExistsCartridgeByPackage );
use DE_EPAGES::Core::API::Error qw( ExistsError GetError );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::Warning qw ( Warning );
use DE_EPAGES::Database::API::Connection qw( RunOnStore );
use DE_EPAGES::WebInterface::API::MessageCenter qw( SynchronizeCache );
use DE_EPAGES::Object::API::Factory qw( LoadObjectByPath );

sub Main {

    local $| = 1;

    my $Password;
    my $StoreName = 'Store';
    my $Help;
    my $ObjectPath;

    GetOptions(
        'help'          => \$Help,
        'passwd=s'      => \$Password,
        'storename=s'   => \$StoreName,
        'path=s'        => \$ObjectPath,
    );

    usage() if $Help;
    print "\nMissing ebay shop environment path!\n" and usage() unless $ObjectPath;

    my $time1 = time;

    RunOnStore(
        Store => $StoreName,
        DBPassword => $Password,
        Sub => sub  {
            # make sure that the cartridge is installed
            unless (ExistsCartridgeByPackage('DE_EPAGES::Ebay')) {
                print "Store: $StoreName : Cartridge Ebay is not installed.\n";
                return;
            }
            GetUserDetails( $ObjectPath );
        },
    );
    my $time2 = time;
    my $seconds = $time2-$time1;
    my $logmsg = sprintf ("need %.3f seconds", $seconds);
    print $logmsg."\n";

    eval { SynchronizeCache(); };
    Warning( GetError() ) if ExistsError();
}

sub usage {
    print <<END_USAGE;
Usage:
    perl $0 [options] [flags]

options:
    -passwd       database user password              ()
    -storename    name of store                       (Store)
    -path         path of eBay shop environment
flags:
    -help         show the command line options

Example:
    perl $0 -storename Store -path /Shops/DemoShop/EbayShopEnvironments/EbayShopEnvironment1
END_USAGE
    exit 2;
}

sub GetUserDetails {
    my ($ObjectPath) = @_;

    my $EbayShopEnv = LoadObjectByPath( $ObjectPath );
    my $RemoteEbay = DE_EPAGES::Ebay::API::Object::RemoteRESTEbay->new('ShopEnvironment'=>$EbayShopEnv);
    my $result = $RemoteEbay->getUserPreferences([
            'ShowSellerPaymentPreferences',
            'ShowSellerExcludeShipToLocationPreference',
            'ShowSellerProfilePreferences',
            'ShowOutOfStockControlPreference']);

    print(Data::Dumper->Dumper($result));
}

RunScript(Sub=>\&Main, Debug=>1);
