#========================================================================================
# package      DE_EPAGES::Event::API::Batch::CategoryEventBatchProcessHandler
# base         DE_EPAGES::Trigger::API::Object::BatchProcessHandler
# state        public
#----------------------------------------------------------------------------------------
# description  BatchProcessHandler for CategoryEvents
#========================================================================================
package DE_EPAGES::Event::API::Batch::CategoryEventBatchProcessHandler;
use base DE_EPAGES::Trigger::API::Object::BatchProcessHandler;

use DE_EPAGES::Event::API::CategoryEventService;

use DE_EPAGES::Event::API::Constants qw (
    EVENT_CATEGORY_CREATION
    EVENT_CATEGORY_DELETION
    EVENT_CATEGORY_UPDATE
);

use strict;



#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new( $hOptions );
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# input        $hOptions |<ul><li>BatchSize - integer > 1 (optional)</li></ul> | ref.hash
# return       $self | self | DE_EPAGES::Event::API::Batch::CategoryEventBatchProcessHandler
#========================================================================================
sub new {
    my $class = shift;
    my ($hOptions) = @_;
    return $class->SUPER::new($hOptions);
}



sub processItemList {
    my $self = shift;

    my $hEvents = {};
    my $aEventItems = $self->items();

    # iterate over events and collect only one event per category
    for my $EventItem (@$aEventItems) {

        my $Category = $EventItem->{'Object'};
        my $CategoryGUID = $Category->guid();

        $hEvents->{$CategoryGUID} = $EventItem;
    }

    my @CategoryGUIDs = keys %$hEvents;
    for my $CategoryGUID (@CategoryGUIDs) {
        my $EventItem = $hEvents->{$CategoryGUID};
        $self->processItem($EventItem);
    }

    $self->cleanupItems();
    return;
}



sub processItem {
    my $self = shift;
    my ($EventItem) = @_;

    my $CategoryEventService = $self->_createCategoryEventService();
    my $EventType = $EventItem->{'Event'};
    my $Category = $EventItem->{'Object'};

    if($EventType eq EVENT_CATEGORY_CREATION) {
        $CategoryEventService->createCategoryCreationEvent($Category);
    }
    elsif($EventType eq EVENT_CATEGORY_UPDATE) {
        $CategoryEventService->createCategoryUpdateEvent($Category);
    }
    elsif($EventType eq EVENT_CATEGORY_DELETION) {
        $CategoryEventService->createCategoryDeletionEvent($Category);
    }
    else {
        warn 'Try to process event type which is not supported';
    }

    return;
}



sub _createCategoryEventService {
    return DE_EPAGES::Event::API::CategoryEventService->new();
}

1;
