#========================================================================================
# package      DE_EPAGES::Event::API::Batch::OrderEventBatchProcessHandler
# base         DE_EPAGES::Trigger::API::Object::BatchProcessHandler
# state        public
#----------------------------------------------------------------------------------------
# description  BatchProcessHandler for OrderEvents
#========================================================================================
package DE_EPAGES::Event::API::Batch::OrderEventBatchProcessHandler;
use base DE_EPAGES::Trigger::API::Object::BatchProcessHandler;

use DE_EPAGES::Event::API::OrderEventService;

use DE_EPAGES::Event::API::Constants qw (
    EVENT_ORDER_CREATION
    EVENT_ORDER_DELETION
    EVENT_ORDER_UPDATE
);

use strict;



#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new( $hOptions );
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# input        $hOptions |<ul><li>BatchSize - integer > 1 (optional)</li></ul> | ref.hash
# return       $self | self | DE_EPAGES::Event::API::Batch::OrderEventBatchProcessHandler
#========================================================================================
sub new {
    my $class = shift;
    my ($hOptions) = @_;
    return $class->SUPER::new($hOptions);
}



sub processItemList {
    my $self = shift;

    my $hEvents = {};
    my $aEventItems = $self->items();

    # iterate over events and collect only one event per order
    for my $EventItem (@$aEventItems) {

        my $Order = $EventItem->{'Object'};
        my $OrderGUID = $Order->guid();

        $hEvents->{$OrderGUID} = $EventItem;
    }

    my @OrderGUIDs = keys %$hEvents;
    for my $OrderGUID (@OrderGUIDs) {
        my $EventItem = $hEvents->{$OrderGUID};
        $self->processItem($EventItem);
    }

    $self->cleanupItems();
    return;
}



sub processItem {
    my $self = shift;
    my ($EventItem) = @_;

    my $OrderEventService = $self->_createOrderEventService();
    my $EventType = $EventItem->{'Event'};
    my $Order = $EventItem->{'Object'};

    if($EventType eq EVENT_ORDER_CREATION) {
        $OrderEventService->createOrderCreationEvent($Order);
    }
    elsif($EventType eq EVENT_ORDER_UPDATE) {
        $OrderEventService->createOrderUpdateEvent($Order);
    }
    elsif($EventType eq EVENT_ORDER_DELETION) {
        $OrderEventService->createOrderDeletionEvent($Order);
    }
    else {
        warn 'Try to process event type which is not supported';
    }

    return;
}



sub _createOrderEventService {
    return DE_EPAGES::Event::API::OrderEventService->new();
}

1;
