use strict;
use DE_EPAGES::Core::API::Script qw (RunScript);
use DE_EPAGES::Database::API::Connection qw (GetCurrentDBHandle Transaction RunOnStore);
use Getopt::Long;
use Time::HiRes;
use JSON;
use URI::Escape;

sub patch_6_15_0 {
    my ($DBI) = @_;

    Transaction ( sub {
        # Replace the old gadgets with the new one. Mark not replacable gadgets with "outdated".
        _UpdateGadgetsAttributes_6_15_0($DBI);
    });

    return;
}

sub _UpdateGadgetsAttributes_6_15_0 {
    my ($DBI) = @_;

        # Get string attributes with gadgets.
        my $aStringAttr = $DBI->execute( <<END_SQL );
            SELECT
                stringattribute.value,
                stringattribute.attributeid,
                stringattribute.objectid
            FROM
                stringattribute
            WHERE
                stringattribute.value LIKE '%data-ep-gadget%';
END_SQL

    foreach my $aString (@$aStringAttr) {
        my $AttributeValue = $aString->[0];

        # Replace old gadgets in current string attribute.
        my $NewAttributeValue = _UpdateGadgetString_6_15_0($AttributeValue);
        my $ObjectID = $aString->[2];
        my $AttributeID = $aString->[1];
        $DBI->do(<<END_SQL, [ $NewAttributeValue, $AttributeID, $ObjectID ]);
        UPDATE
            stringattribute AS attr
        SET
            attr.value = ?
        WHERE
            attr.attributeid = ? AND objectid = ?;
END_SQL
    }


        # Get localized string attributes with gadgets.
        my $aLocalizedStringAttr = $DBI->execute( <<END_SQL );
            SELECT
                localizedstringattribute.value,
                localizedstringattribute.attributeid,
                localizedstringattribute.objectid,
                localizedstringattribute.languageid
            FROM
                localizedstringattribute
            WHERE
                localizedstringattribute.value LIKE '%data-ep-gadget%';
END_SQL

    foreach my $aString (@$aLocalizedStringAttr) {
        my $AttributeValue = $aString->[0];
        # Replace old gadgets in current localized string attribute.
        my $NewAttributeValue = _UpdateGadgetString_6_15_0($AttributeValue);
        my $LanguageID = $aString->[3];
        my $ObjectID = $aString->[2];
        my $AttributeID = $aString->[1];
        $DBI->do(<<END_SQL, [ $NewAttributeValue, $AttributeID, $ObjectID, $LanguageID ]);
        UPDATE
            localizedstringattribute AS attr
        SET
            attr.value = ?
        WHERE
            attr.attributeid = ? AND objectid = ? AND languageid = ?;
END_SQL
    }

    return;
}

sub _UpdateGadgetString_6_15_0 {
    my ($AttributeValue) = @_;

    # Search for old gadgets.
    my $AttributeValueCopy = $AttributeValue;
    while($AttributeValue =~ m/<div.*?data-ep-gadget="(.*?)".*?<\/div>/xsg) {
        # Content of "data-ep-gadget" (jsonstring).
        my $GadgetInfo = $1;
        my $OldGadgetInfo = $GadgetInfo;
        $GadgetInfo =~ s/\&quot;/\"/g;
        $GadgetInfo =~ s/\n/ /g;
        # Check if there are gadget info.
        if(defined $GadgetInfo and $GadgetInfo ne ''){
            # Make perl hash.
            my $hFinal = from_json($GadgetInfo);
            # Get contentclass from the gadget perl hash to identify the gadgets.
            my $GadgetAlias = $hFinal->{'alias'};

            my $ReplaceString;
            if($GadgetAlias =~ /maps$/) {
                my $MapType = defined $hFinal->{'options'}->{'type'} ? $hFinal->{'options'}->{'type'} : undef;
                if(defined($MapType)) {
                    if($MapType eq 'google') {
                        $ReplaceString = _UpdateGoogelMaps_6_15_0($hFinal);
                    } elsif($MapType eq 'bing') {
                        $ReplaceString = _UpdateBingMaps_6_15_0($hFinal);
                    }
                }
            }
            elsif($GadgetAlias =~ /rss$/) {
                $ReplaceString = _UpdateRSS_6_15_0($hFinal)
            }
            elsif($GadgetAlias =~ /externalvideo$/) {
                my $Provider = defined $hFinal->{'options'}->{'provider'} ? $hFinal->{'options'}->{'provider'} : undef;
                if(defined $Provider) {
                    if($Provider =~ /vimeo$/) { $ReplaceString = _UpdateVimeo_6_15_0($hFinal); }
                    elsif($Provider =~ /dailymotion$/) { $ReplaceString = _UpdateDailyMotion_6_15_0($hFinal); }
                    elsif($Provider =~ /myvideo$/) { $ReplaceString = _UpdateMyVideo_6_15_0($hFinal); }
                    elsif($Provider =~ /wideo$/) { $ReplaceString = _UpdateWideo_6_15_0($hFinal); }
                    elsif($Provider =~ /metacafe$/) { $ReplaceString = _UpdateMetaCafe_6_15_0($hFinal); }
                    else { $ReplaceString = $GadgetInfo }
                }
            }
            # Default: Set outdated comments instead of ordinary gadget begin- and endcomment.
            else { $ReplaceString = $GadgetInfo }

            $ReplaceString =~ s/\"/\&quot\;/g;
            # Replace the old gadget with the new one in the current attribute.
            $AttributeValueCopy =~ s/\Q$OldGadgetInfo\E/$ReplaceString/s;

        }
    }

    return $AttributeValueCopy;
}

# MAPS
#Google
sub _UpdateGoogelMaps_6_15_0 {
    my ($hFinal) = @_;

    $hFinal->{'options'}->{'zoom'} = int($hFinal->{'options'}->{'zoom'});
    my $Title = $hFinal->{'options'}->{'title'};
    $Title =~ s/\n/ /;
    $hFinal->{'options'}->{'title'} = $Title;
    my $NewString = to_json($hFinal);

    return $NewString;
}
# Bing
sub _UpdateBingMaps_6_15_0 {
    my ($hFinal) = @_;

    my $Title = $hFinal->{'options'}->{'title'};
    $Title =~ s/\n/ /;
    $hFinal->{'options'}->{'title'} = $Title;

    my $NewString = to_json($hFinal);

    return $NewString;
}

# RSS
sub _UpdateRSS_6_15_0 {
    my ($hFinal) = @_;

    $hFinal->{'options'}->{'onlyHeadlines'} = _checkBoolean_6_15_0($hFinal->{'options'}->{'onlyHeadlines'});
    $hFinal->{'options'}->{'url'} = uri_unescape($hFinal->{'options'}->{'url'});
    $hFinal->{'options'}->{'showImages'} = _checkBoolean_6_15_0($hFinal->{'options'}->{'showImages'});
    $hFinal->{'options'}->{'onlySnippets'} = _checkBoolean_6_15_0($hFinal->{'options'}->{'onlySnippets'});

    my $NewString = to_json($hFinal);

    return $NewString;
}

sub _checkBoolean_6_15_0 {
    my ($Value) = @_;

    if ($Value eq 'true' or $Value eq '1') {
        return 1;
    } elsif ($Value eq 'false' or $Value eq '0') {
        return 0;
    } else {
        return $Value;
    }
}

# ExternalVideo (regular expressions taken from ExternalContent/Data/Public/GUI/de_epages/externalcontent/gadget.js)
# Vimeo
sub _UpdateVimeo_6_15_0 {
    my ($hFinal) = @_;

    $hFinal->{'options'}->{'id'} =~ s/v=//;
    my $NewString = to_json($hFinal);

    return $NewString;
}
# DailyMotion
sub _UpdateDailyMotion_6_15_0 {
    my ($hFinal) = @_;

    $hFinal->{'options'}->{'id'} =~ s/v=//;
    my $NewString = to_json($hFinal);

    return $NewString;
}
# MyVideo
sub _UpdateMyVideo_6_15_0 {
    my ($hFinal) = @_;

    $hFinal->{'options'}->{'id'} =~ s/movie=//;
    my $NewString = to_json($hFinal);

    return $NewString;
}
# Wideo
sub _UpdateWideo_6_15_0 {
    my ($hFinal) = @_;

    $hFinal->{'options'}->{'id'} =~ s/v=//;
    $hFinal->{'options'}->{'provider'} = 'wideofr';

    my $NewString = to_json($hFinal);

    return $NewString;
}
# Metacafe
sub _UpdateMetaCafe_6_15_0 {
    my ($hFinal) = @_;

    $hFinal->{'options'}->{'id'} .= '/';
    my $NewString = to_json($hFinal);

    return $NewString;
}


sub Main {
     local $| = 1;

    my $Password;
    my $StoreName = 'Store';
    my $Help;
    my $NoOutput = 0;

    GetOptions(
        'help'          => \$Help,
        'passwd=s'      => \$Password,
        'storename=s'   => \$StoreName,
        'nooutput=s'     => \$NoOutput,
    );

    usage() if $Help;
    my $time1 = time;

    RunOnStore(
        Store => $StoreName,
        DBPassword => $Password,
        Sub => sub  {
            patch_6_15_0(GetCurrentDBHandle());
        }
    );

    printf( "need %.1f seconds\n", time-$time1 ) if $NoOutput;
}

sub usage {
    print <<END_USAGE;
Description:
    With 6.15.0 ePages introduced the new gadgets.
    Therefore this script replaces the old with the new ones direct in all string-, localizedstringattributes values.
    Some gadgets does not exist in the 6.15.0 anymore. Those will marked as "outdated".

Usage:
    perl $0 [options] [flags]

options:
    -passwd     database user password              ()
    -storename  name of store                       (Store)

flags:
    -help       show the command line options

Example:
    perl $0
END_USAGE
    exit 2;
}

RunScript(
    'Sub' => \&Main
);
