#========================================================================================
# package      DE_EPAGES::Forum::API::Attributes::ForumPost_Ext
# state        private
# base         DE_EPAGES::Object::API::BaseAttribute
# description  Attribute interface for ForumPost.
#========================================================================================
package DE_EPAGES::Forum::API::Attributes::ForumPost_Ext;
use base qw( DE_EPAGES::Object::API::BaseAttribute );

use strict;
use DE_EPAGES::Forum::DAL::Forum qw( DAL_GetLastVisiblePostInThread
                                     DAL_CountVisibleRepliesInThread DAL_CountPostsInThread
                                     DAL_GetNextVisibleThread DAL_GetPreviousVisibleThread );

##no critic qw(ProhibitCascadingIfElse)

#========================================================================================
# function     getAttributes
# state        private
#----------------------------------------------------------------------------------------
# syntax       $hValues = $Package->( $Object, $aNames );
# example      # never call getAttributes directly!
#               $Value = $Object->get( $AttributeName );
#----------------------------------------------------------------------------------------
# description  Returns attribute values of an object.
#               Used by <function DE_EPAGES::Object::Object::Object::get>
#----------------------------------------------------------------------------------------
# input        $Object | object | object
# input        $aNames | list of attribute names | ref.array
# return       $hValues | attribute name => value hash | ref.hash
#========================================================================================
sub getAttributes {

    shift;
    my ($Object, $aNames, $LanguageID) = @_;
    my $hInfo = {};
    foreach my $Name (@$aNames) {

        if ($Name eq 'LastPostID') {
            $hInfo->{$Name} = DAL_GetLastVisiblePostInThread( $Object->id );
        }
        elsif ($Name eq 'LastReplyID') {
            my $LastPostID = DAL_GetLastVisiblePostInThread( $Object->id );
            $hInfo->{$Name} = $LastPostID == $Object->id ? undef : $LastPostID;
        }
        elsif ($Name eq 'IsThread') {
            $hInfo->{$Name} = $Object->parent->instanceOf('Forum');
        }
        elsif ($Name eq 'Posts') {
            $hInfo->{$Name} = _getPosts($Object);
        }
        elsif ($Name eq 'VisiblePosts') {
            $hInfo->{$Name} = [ grep { $_->get('IsVisible') } @{$Object->get('Posts')} ];
        }
        elsif ($Name eq 'Replies') {
            $hInfo->{$Name} = _getReplies($Object);
        }
        elsif ($Name eq 'VisibleReplies') {
            $hInfo->{$Name} = [ grep { $_->get('IsVisible') } @{$Object->get('Replies')} ];
        }
        elsif ($Name eq 'VisibleRepliesCount') {
            $hInfo->{$Name} = DAL_CountVisibleRepliesInThread( $Object->id );
        }
        elsif ($Name eq 'PostsCount') {
            $hInfo->{$Name} = DAL_CountPostsInThread( $Object->id );
        }
        elsif ($Name eq 'ReplyLevel') {
            my $ReplyLevel = 0;
            my $ForumPost = $Object;
            while ($ForumPost = $ForumPost->parentByClass('ForumPost')) {
                last unless $ForumPost;
                $ReplyLevel++;
            }
            $hInfo->{$Name} = $ReplyLevel;
        }
        elsif ($Name eq 'Name') {
            $hInfo->{$Name} = $Object->get('Subject');
        }
        elsif ($Name eq 'NextThreadID') {
            $hInfo->{$Name} = DAL_GetNextVisibleThread( $Object->get('Forum')->id, $Object->get('Thread')->id );
        }
        elsif ($Name eq 'PreviousThreadID') {
            $hInfo->{$Name} = DAL_GetPreviousVisibleThread( $Object->get('Forum')->id, $Object->get('Thread')->id );
        }
    }
    return $hInfo;
}

sub _getPosts {
    my ($ParentPost) = @_;
    my @Posts;
    push @Posts, $ParentPost;
    my $Children = $ParentPost->childrenByClass('ForumPost');
    foreach my $Post (@$Children) {
        push @Posts, @{_getPosts($Post)};
    }
    return \@Posts;
}

sub _getReplies {
    my ($ParentPost) = @_;
    my @Posts;
    my $Children = $ParentPost->childrenByClass('ForumPost');
    foreach my $Post (@$Children) {
        push @Posts, $Post;
        push @Posts, @{_getReplies($Post)};
    }
    return \@Posts;
}

1;
