#========================================================================================
# package      DE_EPAGES::Forum::API::Attributes::Forum_Ext
# base         DE_EPAGES::Object::API::BaseAttribute
# state        private
# description  Implements calculated attributes
#========================================================================================
package DE_EPAGES::Forum::API::Attributes::Forum_Ext;
use base qw( DE_EPAGES::Object::API::BaseAttribute );

use strict;
use DE_EPAGES::Object::API::Factory qw (LoadObject);
use DE_EPAGES::Forum::DAL::Forum qw (DAL_GetUsersByForum);

##no critic qw(ProhibitCascadingIfElse)

#========================================================================================
# function     getAttributes
# state        private
# syntax       $Value = $Object->get($AttributeName);
#========================================================================================
sub getAttributes {
    shift;
    my ($Object, $aNames) = @_;

    my $hInfo = {};

    foreach my $Name (@$aNames) {
        if ($Name eq 'Threads') {
            $hInfo->{$Name} = $Object->childrenByClass('ForumPost');
        }
        elsif ($Name eq 'VisibleThreads') {
            $hInfo->{$Name} = [ grep { $_->get('IsVisible') } @{$Object->get('Threads')} ];
        }
        elsif ($Name eq 'Posts') {
            my $Threads = $Object->childrenByClass('ForumPost');
            my @Posts = map { @{$_->get('Posts')} } @$Threads;
            $hInfo->{$Name} = \@Posts;
        }
        elsif ($Name eq 'VisiblePosts') {
            $hInfo->{$Name} = [ grep { $_->get('IsVisible') } @{$Object->get('Posts')} ];
        }
        elsif ($Name eq 'Users') {
            $hInfo->{$Name} = [
                sort { lc $a->get('NameOrAlias') cmp lc $b->get('NameOrAlias') }
                map { LoadObject($_) }
                @{ DAL_GetUsersByForum( $Object->id ) }
            ];
        }
        elsif ($Name eq 'LastPostID') {
            my $Threads = $Object->childrenByClass('ForumPost');
            my $newestPost;
            foreach my $Thread (@$Threads) {
                my $newestPostInThread = $Thread->get('LastPost');
                if(!$newestPost || !$newestPostInThread ||
                   $newestPost->get('CreationDate') > $newestPostInThread->get('CreationDate')) {
                    $newestPost = $newestPostInThread;
                }
            }
            $hInfo->{$Name} = $newestPost->id if defined $newestPost;
        }
        elsif ($Name eq 'ThreadsCount') {
            $hInfo->{$Name} = scalar(@{$Object->findChildren});
        }
        elsif ($Name eq 'SeoCheckRatings') {
            $hInfo->{$Name} = {
                'Title'             => 0.35,
                'Url'               => 0.15,
                'Description'       => 0.2,
                'AdvDescription'    => 0.2,
                'CategoryImage'     => 0.1,
            };
        }
    }

    return $hInfo;
}

1;
