#========================================================================================
# package      DE_EPAGES::MultiStoreCommon::Hooks::ObjectExport
# state        public
# description  Listens to events on objects and triggers appropriate functions.
#========================================================================================
package DE_EPAGES::MultiStoreCommon::Hooks::ObjectExport;

use strict;
use DE_EPAGES::MultiStoreCommon::API::Synchronization qw( GetDefaultValues );
use DE_EPAGES::Object::API::Factory qw( SplitObjectPath JoinObjectPath );

#========================================================================================
# function     OnTransformExportXML
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnTransformExportXML($hParams);
#----------------------------------------------------------------------------------------
# description  API_MS_TransformExportXML triggered
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>TagName - String</li>
#                   <li>hAttributes - ref.hash</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnTransformExportXML {
    my ($hParams) = @_;

    my $TagName = $hParams->{'TagName'};
    my $hAttributes = $hParams->{'hAttributes'};

    my $hDefaultValues = GetDefaultValues();

    if($TagName eq 'SelectedVariation'){
        if( exists $hAttributes->{'Path'} ) {
            # update product type name
            my $aPath = SplitObjectPath( $hAttributes->{'Path'} );
            ## no critic qw(ProhibitMagicNumbers)
            $aPath->[-5] = "MS_$aPath->[-5]";
            splice @$aPath, -5, 0, 'ProductTypes' if( $aPath->[-5] eq $hDefaultValues->{'MS_PRODUCT_CLASS_ALIAS'} );
            ## use critic
            $hAttributes->{'Path'} = JoinObjectPath( $aPath );
        }
    }
    elsif($TagName eq 'Product'){
        if( exists $hAttributes->{'ProductType'} ) {
            $hAttributes->{'ProductType'} = "MS_$hAttributes->{'ProductType'}";
        }
    }
    elsif($TagName eq 'ProductType'){
        if( exists $hAttributes->{'Alias'} ){
            $hAttributes->{'Alias'} = "MS_$hAttributes->{'Alias'}";
        }
        $hAttributes->{'Class'} = 'SubShopProductType';
        $hAttributes->{'Package'} = 'DE_EPAGES::MultiStore::API::Object::SubShopProduct';
        $hAttributes->{'Base'} = './' . $hDefaultValues->{'MS_PRODUCT_CLASS_ALIAS'} if $hAttributes->{'Base'} eq '../ProductClass';
        $hAttributes->{'Base'} = '/Classes/SubShopProduct' if $hAttributes->{'Base'} eq '/Classes/Product';
    }
    elsif($TagName eq 'ProductAttribute'){
        $hAttributes->{'Class'} = 'SubShopProductAttribute';
    }
    elsif($TagName eq 'Category' or $TagName eq 'CategorySpecialOffer'){
        $hAttributes->{'Class'} = 'SubShopCategory';
        delete $hAttributes->{'Parent'};
    }

    return;
}

1;
