#========================================================================================
# package      DE_EPAGES::Object::API::Attributes::System_DefaultExt
# state        private
# base         DE_EPAGES::Object::API::Attributes::DefaultAttribute
# description  attributes are saved at default attributes all static pages are removed.
#========================================================================================
package DE_EPAGES::Object::API::Attributes::System_DefaultExt;
use base qw( DE_EPAGES::Object::API::Attributes::DefaultAttribute );

use strict;

use DE_EPAGES::Core::API::EpagesConfig qw ( EpagesConfig );
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

sub getAttributes {
    my $self = shift;
    my ($Object, $aNames, $LanguageID) = @_;

    my $hInfo = {};

    foreach my $Name (@$aNames) {
        if (ElementOf($Name,
                qw(UnityUrlScheme UnityApiUrlScheme UnityWebServerPort
                   UnitySSLWebServerPort UnityUseSubdomainRouting))) {
            $hInfo->{$Name} = $self->getFromDatabaseOrEpagesConfig($Object, $Name);
        }
    }

    return $hInfo;
}

sub getFromDatabaseOrEpagesConfig {
    my $self = shift;
    my ($Object, $Name) = @_;

    my $SuperValue = $self->SUPER::getAttributes($Object, [$Name])->{$Name};

    return defined $SuperValue ? $SuperValue : EpagesConfig->get('DE_EPAGES::Object', $Name);
}

sub setAttributes {
    my $self = shift;
    my ($Object, $hValues) = @_;

    $self->SUPER::setAttributes(@_);

    $Object->clearPageCache() if (['WebServerPort', 'SSLWebServerPort'] ~~ %$hValues);

    return;
}

1;
