#========================================================================================
# package      DE_EPAGES::Order::API::Attributes::LineItemShipping_Ext
# state        private
# description  Attribute interface for LineItemShipping.
#========================================================================================
package DE_EPAGES::Order::API::Attributes::LineItemShipping_Ext;
use base qw( DE_EPAGES::Object::API::BaseAttribute );

use strict;

sub getAttributes {
    my $self = shift;
    my ($Object, $aNames) = @_;
    my $hInfo = {};
    foreach my $Name (@$aNames) {
        if ($Name eq 'Taxes') {
            $hInfo->{$Name} = $self->_shippingTaxes($Object);
        }
    }
    return $hInfo;
}



# get the shipping prices in a loop for each tax rate
# e.g. if we have 5,- shipping and products with 7% and 19% tax,
# shipping is splitted to the relation of the 7% and 19% produts of th total price
# from each shipping price the tax is calculated
sub _shippingTaxes {
    my $self = shift;
    my ($LineItemShipping) = @_;

    # get the TaxLineItems from Container
    my $Container = $LineItemShipping->container;
    my $aTaxLineItems = $Container->get('Taxes');
    my $NoTax = $Container->get('NoTax');

    # if the customer has removed a TaxClass, we do not calculate the splitten tax amounts
    return [] if $Container->get('IsTaxClassRemoved');

    my $hTaxRates = $Container->netPricesForTax();
    my $hShippingTaxItems = $hTaxRates->{'LineItemShipping'};
    my $Formatter = $Container->formatter;

    my $aRet;
    foreach my $TaxLineItem (@$aTaxLineItems) {

        my $TaxArea = $TaxLineItem->get('TaxArea');
        my $TaxClass = $TaxLineItem->get('TaxClass');
        return [] unless defined $TaxClass;

        my $TaxRate = defined $TaxArea
        ? ($NoTax ? 0 : $Container->taxRate($TaxClass))
        : $TaxLineItem->get('TaxRate');
        my $Value = defined $hShippingTaxItems->{$TaxClass->id} ? $Formatter->round($hShippingTaxItems->{$TaxClass->id}) : 0;


        if (defined $Value and $Value != 0){

            push @$aRet, {'TaxClass' => $TaxClass,
                          'TaxRate' =>  $TaxRate,
                          'Value'      => $Value,
                          'TaxAmount' =>  $TaxLineItem->calculateTaxAmount($hShippingTaxItems->{$TaxClass->id}, $TaxRate, $TaxRate),
                         }
        }
    }
    return $aRet;
}

1;
