#========================================================================================
# package      DE_EPAGES::Order::API::Resource::CartCheckoutButton
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for the checkout buttons of the cart.
#========================================================================================
package DE_EPAGES::Order::API::Resource::CartCheckoutButton;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Core::API::Error qw ( Error );
use DE_EPAGES::Order::API::PickupTokenExpiration;

use strict;

sub service {
    return LoadObjectByPath('/RestServices/CartCheckoutButton');
}

sub class {
    return 'Basket';
}

sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ]
    }->{$RequestMethod};
}

sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/carts/([^/]+)/checkoutbutton/?$|;
    return $1;
}

sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    return [ $Object ];
}

sub get {
    my $self = shift;
    my ($Basket) = @_;

    if($self->_isBasketExpired($Basket)) {
        Error('ResourceNotFound', {
            'GUID' => $Basket->guid(),
            'Class' => $self->class(),
            'Site' => $Basket->getSite()->pathString(),
        });
    }

    $self->_validateLineItems($Basket);

    my $aPaymentMethods = $Basket->get('Shop')->get('PaymentMethods');
    my $aCheckoutButtons;
    foreach my $PaymentMethod (@{$aPaymentMethods}) {
        push (@{$aCheckoutButtons}, $PaymentMethod->getAlternativeCheckoutButtonInfo($Basket));
    }

    return {
        items => $aCheckoutButtons,
    };
}


sub _isBasketExpired {
    my $self = shift;
    my ($Basket) = @_;

    my $BasketCreationDate = $Basket->get('CreationDate');
    my $PickupTokenExpiration = DE_EPAGES::Order::API::PickupTokenExpiration->new();
    my $IsExpired = $PickupTokenExpiration->isExpired($BasketCreationDate);

    return $IsExpired;
}

sub _validateLineItems{
    my $self = shift;
    my ($Basket) = @_;

    my $LineItemContainer = $Basket->get('LineItemContainer');
    if (defined $LineItemContainer){
        return;
    }
    Error('Gone', {'reason' => 'This cart was already used for creating an order!'});

}


1;
