#========================================================================================
# package      DE_EPAGES::Order::API::Resource::OrderWithCustomerCreationResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for Order with new Customer Creation given Cart/Basket.
#========================================================================================
package DE_EPAGES::Order::API::Resource::OrderWithCustomerCreationResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Object::API::Object::Locale;
use DE_EPAGES::Core::API::Url qw (ParseQueryString);
use DE_EPAGES::Order::API::OrderService;
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::Trigger::API::BatchProcessor qw ( RunBatchProcess );

use strict;



sub service {
    return LoadObjectByPath('/RestServices/OrderWithCustomerCreationResource');
}

sub class {
    return 'Basket';
}

sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        POST => [
            ['post', 'application/vnd.epages.v1+json'],
            ['post', 'application/json'],
        ],
    }->{$RequestMethod};
}

sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/carts/([^/]+)/order/?$|;
    return $1;
}

sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if ( $ActionName eq 'post' ) {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        return [ $Object, $LocaleID ];
    }
    else {
        return [ $Object ];
    }
}


sub post {
    my $self = shift;
    my ($Basket, $LocaleID) = @_;

    my $Shop = $Basket->getSite();
    my $Context = $self->_createShopRequestContext($Shop);
    $LocaleID = $Context->validLocale($LocaleID);

    my $OrderData;
    $self->_RunBatchProcess(['CreateOrders', 'UpdateProducts'], sub {
        my $OrderService = $self->_createOrderService();
        $OrderData = $OrderService->createOrderAndCustomer($Basket, $LocaleID);
    });
    return $OrderData
}

sub _createOrderService {
    my $self = shift;
    return DE_EPAGES::Order::API::OrderService->new();
}

sub _createShopRequestContext {
    my $self = shift;
    my ($Shop) = @_;
    return DE_EPAGES::Shop::API::Resource::ShopRequestContext->new($Shop);
}

sub _RunBatchProcess {
    my $self = shift;
    my ($BatchTaskName, $cSub) = @_;
    RunBatchProcess($BatchTaskName, $cSub);
    return;
}

1;
