#========================================================================================
# package      DE_EPAGES::Order::API::Resource::SaleResource
# state        public
#----------------------------------------------------------------------------------------
# description  Sale resource.
#========================================================================================
package DE_EPAGES::Order::API::Resource::SaleResource;
use base DE_EPAGES::Order::API::Resource::BaseSaleResource;

use DE_EPAGES::Core::API::Error qw (Error);
use DE_EPAGES::Core::API::Object::DateTimeFormatter;
use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Order::API::Sale::SaleSummary;

use strict;



sub service {
    return LoadObjectByPath('/RestServices/Sale');
}



sub match {
    my $self = shift;
    my ($Request) = @_;
    return unless $Request->uri->path =~ m|^/api/sales/?$|;
    return 1;
}



sub params {
    my $self = shift;
    my ( $ActionName, $Object, $Request ) = @_;

    if ($ActionName eq 'get') {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $CreatedAfter = $self->convertToDatetime($hQuery->{'createdAfter'}->[0]);
        my $CreatedBefore = $self->convertToDatetime($hQuery->{'createdBefore'}->[0]);
        return [ $Object, $CreatedAfter, $CreatedBefore ];
    }
    else {
        return [$Object];
    }
}



sub get {
    my $self = shift;
    my ( $Object, $CreatedAfterString, $CreatedBeforeString ) = @_;

    my $Shop        = $Object->getSite();
    my $SaleSummary = DE_EPAGES::Order::API::Sale::SaleSummary->new($Shop);

    return $SaleSummary->get( $CreatedAfterString, $CreatedBeforeString );
}



sub convertToDatetime {
    my $self = shift;
    my ($DateTimeString) = @_;

    if(!defined $DateTimeString) {
        Error('Called GET api/sales without createdAfter or createdBefore query param!');
    }

    my $DateTimeFormatXML = DE_EPAGES::XML::API::DateTimeFormatXML->new();
    return $DateTimeFormatXML->parse_datetime( $DateTimeString, 'UTC' );
}

1;
