#========================================================================================
# package      DE_EPAGES::Order::t::OtherLineItemsData_testTranslations
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  integration test for DE_EPAGES::Order::API::OtherLineItemsData
#               test the translation files
#========================================================================================
package DE_EPAGES::Order::t::OtherLineItemsData_testTranslations;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Order::API::OtherLineItemsData;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::EpagesObject;
use DE_EPAGES::Test::Mock::Mockery;
use Test::More;

use strict;



sub test {
    my $self = shift;

    $self->test_getLineItemsData();

    done_testing();
}

sub test_getLineItemsData {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createObjects();
    my $LineItemsData = $Mockery->get('SUT');

    my $LineItemContainer = $Mockery->get('LineItemContainer');
    my $Formatter = $Mockery->get('Formatter');
    my $LanguageID = '1';
    my $IncludeTaxInLineItem = 1;

    my $hLineItemsData = $LineItemsData->getOtherLineItems($LineItemContainer, $Formatter, $LanguageID, $IncludeTaxInLineItem);
    my $hExpectedLineItemsData = $self->_createExpectedOtherLineItemsData();
    is_deeply($hLineItemsData, $hExpectedLineItemsData, "$SubTestName - test if expected LineItemContainer data was returned.");


}


sub _createObjects {
    my $self = shift;

    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();
    $Mockery->register('LineItemContainer', ['LineItemProduct1', 'Shop', 'LineItemShippingOption', 'LineItemGlobalValueDiscount', 'LineItemEcoParticipation', 'LineItemDeposit'], sub {
        my ($LineItemProduct1, $Shop, $LineItemShippingOption, $LineItemGlobalValueDiscount, $LineItemEcoParticipation, $LineItemDeposit) = @_;
        my $LineItemContainer = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Order::API::Object::LineItemContainer', {
            'TaxModel' => 'GROSS',
            'CurrencyID' => 'EUR',
            'LineItems' => [
                $LineItemProduct1
            ],
            'Children' => [
                $LineItemProduct1,
                $LineItemShippingOption,
                $LineItemGlobalValueDiscount,
                $LineItemDeposit,
                $LineItemEcoParticipation
            ],
            'Site' => $Shop,
        });

        $LineItemContainer->mock('childrenByClass', sub {
            my $MockedSelf = shift;
            my ($ClassAlias) = @_;

            if ( $ClassAlias eq 'LineItemProduct' ) {
              return [$LineItemProduct1];
            }
        });

        $LineItemProduct1->set({'Parent' => $LineItemContainer});
        $LineItemShippingOption->set({'Parent' => $LineItemContainer});
        $LineItemGlobalValueDiscount->set({'Parent' => $LineItemContainer});
        $LineItemDeposit->set({'Parent' => $LineItemContainer, 'LineItemContainer' => $LineItemContainer});
        $LineItemEcoParticipation->set({'Parent' => $LineItemContainer});
        return $LineItemContainer;
    });

    $Mockery->extend($self->_createCommonMocks());

    return $Mockery->assemble();
}


sub _createCommonMocks {
    my $self = shift;
    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    $Mockery->register('SUT', ['Context'], sub {
        my ($Context) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Order::API::OtherLineItemsData', []);
        $Mockify->addMockWithReturnValueAndParameterCheck('_createShopRequestContext', $Context, [{'object'=> 'DE_EPAGES::Shop::API::Object::Shop'}]);
        $Mockify->addMockWithReturnValueAndParameterCheck('_GetInfoLanguage', { 'Code2' => 'de', }, ['int']);
        return $Mockify->getMockObject();
    });

    $Mockery->register('Shop', [], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {});
        $Mockify->addMockWithReturnValueAndParameterCheck('siteLocale', 'en_GB', [{'string' => 'en_GB'}]);
        return $Mockify->getMockObject();
    });

    $Mockery->register('Formatter', ['Shop'], sub {
        my ($Shop) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Shop::API::Resource::Formatter', [$Shop, 'en_GB']);
        $Mockify->addMock('quantity', sub {
            my $MockedSelf = shift;
            my ($Quantity, $Unit) = @_;
            return $Quantity;
        });
        $Mockify->addMock('price', sub {
            my $MockedSelf = shift;
            my ($Price, $Currency, $TaxModel) = @_;
            return $Price;
        });
        return $Mockify->getMockObject();
    });

    $Mockery->register('LineItemShippingOption', ['TaxClass'], sub {
        my ($TaxClass) = @_;
        my $LineItemShippingOption = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::ShippingOption::API::Object::LineItemShippingOption', {
            'instanceOf' => 'LineItemShippingOption',
            'LineItemPrice' => 2.00,
            'Name' => 'Gift wrap',
            'TaxClass' => $TaxClass,
            'TaxClassDigital' => undef,
            'TaxRate' => 0.19,
        });
        return $LineItemShippingOption->getMockObject();
    });

    $Mockery->register('LineItemGlobalValueDiscount', ['TaxClass'], sub {
        my ($TaxClass) = @_;
        my $LineItemGlobalValueDiscount = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::PriceList::API::Object::LineItemGlobalValueDiscount', {
            'instanceOf' => 'LineItemGlobalValueDiscount',
            'LineItemPrice' => -10.00,
            'Name' => 'Basket Discount',
            'TaxClass' => $TaxClass,
            'TaxClassDigital' => undef,
            'TaxRate' => 0.19,
        });
        return $LineItemGlobalValueDiscount->getMockObject();
    });

    $Mockery->register('LineItemEcoParticipation', ['TaxClass'], sub {
        my ($TaxClass) = @_;
        my $LineItemEcoParticipation = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Product::API::Object::LineItemEcoParticipation', {
            'instanceOf' => 'LineItemEcoParticipation',
            'LineItemPrice' => 2.99,
            'Name' => 'EcoParticipation',
            'TaxClass' => $TaxClass,
            'TaxClassDigital' => undef,
            'TaxRate' => 0.19,
        });
        return $LineItemEcoParticipation->getMockObject();
    });

    $Mockery->register('LineItemDeposit', ['TaxClass'], sub {
        my ($TaxClass) = @_;
        my $LineItemEcoParticipation = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Product::API::Object::LineItemDeposit', {
            'Alias' => 'LineItemProduct_57FD022C-D6D0-F057-398B-AC15320B2567_Deposit',
            'instanceOf' => 'LineItemDeposit',
            'LineItemPrice' => 2.23,
            'Name' => 'LineItemDeposit',
            'TaxClass' => $TaxClass,
            'TaxClassDigital' => undef,
            'TaxRate' => 0.19,
            'LineItemContainer' => undef,
        });
        return $LineItemEcoParticipation->getMockObject();
    });

    $Mockery->register('LineItemProduct1', ['TaxClass'], sub {
        my ($TaxClass) = @_;
        my $LineItemProduct = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Product::API::Object::LineItemProduct', {
            'BasePrice' => 32.99,
            'GUID' => '123-35-56562-324352',
            'instanceOf' => 'LineItemProduct',
            'LineItemPrice' => 32.99,
            'Name' => 'LineItemProduct',
            'Quantity' => 2,
            'Product' => 'My Product',
            'SKU' => 'abc_12345346',
            'TaxClass' => $TaxClass,
            'TaxClassDigital' => undef,
            'TaxRate' => 0.19,
            'Weight' => 4.89,
            'WeightQuantity' => 1,
            'WeightUnit' => 'kg',
            'LocalizedVariationString' => undef,
            'LineItemDeposit' => undef,
        });
        return $LineItemProduct->getMockObject();
    });

    $Mockery->register('Context', ['Shop'], sub {
        my ($Shop) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Shop::API::Resource::ShopRequestContext', [$Shop]);
        $Mockify->addMockWithReturnValue('apiBaseUrl', 'http://baseurl.test.org');
        $Mockify->addMockWithReturnValue('imageBaseUrl', 'http://image.baseurl.test.org');
        return $Mockify->getMockObject();
    });

    $Mockery->register('TaxClass', [], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Tax::API::Object::TaxClass', {
            'GUID' => '123-456-7890',
            'Name' => 'TaxClassName',
        });
        return $Mockify->getMockObject();
    });

    return $Mockery;
}

sub _createExpectedOtherLineItemsData {
    return [
          { 'taxClass' => {
               'taxClassId' => '123-456-7890',
               'name' => 'TaxClassName',
               'percentage' => '19'
             },
            'name' => 'Versandoption',
            'lineItemPrice' => '2',
            'type' => 'shippingOption',
          },
          { 'taxClass' => {
              'taxClassId' => '123-456-7890',
              'name' => 'TaxClassName',
              'percentage' => '19'
            },
            'name' => 'Warenkorbrabatt',
            'lineItemPrice' => '-10',
            'type' => 'basketDiscount'
          },
          { 'taxClass' => {
             'taxClassId' => '123-456-7890',
             'name' => 'TaxClassName',
             'percentage' => '19'
           },
           'name' => 'Pfand',
           'lineItemPrice' => '2.23',
           'type' => 'deposit',
           'lineItemProductGuid' => ''
          },
          { 'taxClass' => {
              'taxClassId' => '123-456-7890',
              'name' => 'TaxClassName',
              'percentage' => '19'
            },
           'name' => 'Vorgezogene Recyclinggebhr',
           'lineItemPrice' => '2.99',
           'type' => 'ecoParticipation'
          }
        ];
}


__PACKAGE__->runScript();
