#========================================================================================
# package      DE_EPAGES::Packlink::Hooks::AppStore
# state        private
#========================================================================================
package DE_EPAGES::Packlink::Hooks::AppStore;

use DE_EPAGES::Core::API::TestParameter qw ( TestObject );
use DE_EPAGES::ExternalShipping::API::Log qw ( LogShippingFulfillment );
use DE_EPAGES::Packlink::API::Object::ShippingProviderMethodPacklink;
use DE_EPAGES::Packlink::API::ShippingMethodPacklink;

use strict;

#========================================================================================
# function     OnCustomizeAppLinks
# state        private
#----------------------------------------------------------------------------------------
# syntax       OnCustomizeAppLinks( $hInfo );
#----------------------------------------------------------------------------------------
# description  Manipulates the links in the appstore to point to Packlink creation page.
#----------------------------------------------------------------------------------------
# input        $hInfo | hash from UI_CustomizeAppLinks | ref.hash
#========================================================================================
sub OnCustomizeAppLinks {
    my ($hInfo) = @_;

    if($hInfo->{'App'}->{'supportWebsite'} =~ /\.packlink\./i) {
        my $Shop = $hInfo->{Shop};
        TestObject( 'Shop', $Shop, 'DE_EPAGES::Shop::API::Object::Shop' );

        my $aLinks = $hInfo->{'AppLinks'}->{'links'};

        for ( my $i = 0; $i < scalar @$aLinks; ++$i) {
            my $link = $aLinks->[$i];

            if ($link->{'rel'} eq 'installApp') {
                $link->{'href'} = $Shop->isUnity() ?
                        '?ViewAction=UnityMBO-ViewPacklinkConsecution'
                        : '?ViewAction=MBO-ViewPacklinkConsecution';
                my $appID = $hInfo->{'App'}->{'id'};
                $link->{'href'} .= '&appID=' . $appID;
                LogShippingFulfillment('Packlink', 'appID', $appID, 'OnCustomizeAppLinks');
            }
            elsif($link->{'rel'} eq 'uninstallApp') {
                my $ShippingMethodPacklink = DE_EPAGES::Packlink::API::ShippingMethodPacklink->new();
                my $PacklinkProviderMethod = $ShippingMethodPacklink->getShippingProviderMethodPacklink($Shop);
                my $PacklinkID = $PacklinkProviderMethod->get('PacklinkID');
                $link->{'href'} = $Shop->isUnity() ?
                        '?ViewAction=UnityMBO-ViewPacklinkAuthorization'
                        : '?ViewAction=MBO-ViewPacklinkAuthorization';
                $link->{'href'} .= '&appID='. $hInfo->{'App'}->{'id'} . '&PacklinkID=' . $PacklinkID.'&uninstall=1';
                LogShippingFulfillment('Packlink', 'PacklinkID', $PacklinkID, 'OnCustomizeAppLinks');
            }
        }
    }

    return;
}

1;
