#========================================================================================
# package      DE_EPAGES::PriceList::API::CSV::PriceListCustomerSpecificsExportDriver;
# base         DE_EPAGES::ShopCSVExportImport::API::CSV::ShopObjectExportDriver
# state        public
#----------------------------------------------------------------------------------------
# description  This module implements a handler to export shop PriceLists via csv
#               This exports only customer specific prices, that is, everything except for
#               the default UNITY pricelist.
# example      use DE_EPAGES::PriceList::API::CSV::PriceListCustomerSpecificsExportDriver;
#               DE_EPAGES::PriceList::API::CSV::PriceListCustomerSpecificsExportDriver->exportCSV($FileName, $hFileFormat, $aColumns, $Shop );
#========================================================================================
package DE_EPAGES::PriceList::API::CSV::PriceListCustomerSpecificsExportDriver;
use base qw( DE_EPAGES::PriceList::API::CSV::PriceListExportDriver );

use strict;
use DE_EPAGES::Core::API::Warning qw( Warning );
use DE_EPAGES::PriceList::API::PriceList qw (GetUnityPriceList);

#========================================================================================
# function     items
# state        public
#----------------------------------------------------------------------------------------
# syntax       my $Items = $self->items();
#----------------------------------------------------------------------------------------
# description  Remove all prices other than from the standard 'Unity' price list (bulk prices)
#----------------------------------------------------------------------------------------
# return       $ahData | parameter of exportCSV | ref.array.hash
#               <ul>
#                   <li>Product | product object | object
#                   <li>PriceList | pricelist object | object
#                   <li>Quantity | quantity for price and / or discount | float
#                   <li>Price | scaleprice | float
#                   <li>Discount | quantitydiscount as percental value | float
#                   <li>Value | value for discount | float
#                   <li>ValueDiscount | valuediscount as percental value | float
#               </ul>
#========================================================================================
sub items {
    my $self = shift;

    my $Shop = $self->{'Object'};

    my $ahItems = $self->SUPER::items();
    my $UnityPriceList = GetUnityPriceList($Shop, 1);

    #-- For the 'default' price list in NOW, we don't touch, that is handled by the 'Simple' export module, and it is a distinct export option
    for(my $i = 0; $i < scalar(@$ahItems); $i++) {
        my $PriceList = $ahItems->[$i]->{'PriceList'};
        if ( $PriceList->id == $UnityPriceList->id ) {
            splice(@$ahItems, $i, 1);
            $i--;
            next;
        }
    }

    my $ItemCount = scalar(@$ahItems);
    Warning('NO_PRICELISTITEMS') unless $ItemCount;
    my $Monitor = $self->monitor;
    $Monitor->set({'Total'=> $ItemCount}) if defined $Monitor;
    return $ahItems;
}

1;
