#========================================================================================
# package      DE_EPAGES::PriceList::API::CSV::PriceListCustomerSpecificsExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  This module implements the high level interface for import and export of
#               PriceLists to CSV files.
#               This exports only customer specific prices, that is, everything except for
#               the default UNITY pricelist.
#========================================================================================
package DE_EPAGES::PriceList::API::CSV::PriceListCustomerSpecificsExportImport;
use base DE_EPAGES::PriceList::API::CSV::PriceListExportImport;

use strict;
use DE_EPAGES::PriceList::API::Constants qw( @CSV_WARNING_CODES_PRICELIST );
use DE_EPAGES::PriceList::API::CSV::PriceListCustomerSpecificsExportDriver;

#========================================================================================
# function     exportDriver
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Driver->exportDriver();
#----------------------------------------------------------------------------------------
# description  Return driver package.
#----------------------------------------------------------------------------------------
# return       $DriverPackage  | package to driver | string
#========================================================================================
sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::PriceList::API::CSV::PriceListCustomerSpecificsExportDriver';
}

#========================================================================================
# function     importDriver
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Driver->importDriver();
#----------------------------------------------------------------------------------------
# description  Return driver package.
#----------------------------------------------------------------------------------------
# return       $DriverPackage  | package to driver | string
#========================================================================================
sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::PriceList::API::CSV::PriceListImportHandler';
}

#========================================================================================
# function     csvAttributes
# state        public
#----------------------------------------------------------------------------------------
# syntax       my $aCSVAttributes = $Driver->csvAttributes($Shop, $LocaleID, $aLanguageCode2s);
#----------------------------------------------------------------------------------------
# description  Return list of exportable csv attributes.
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $LocaleID | locale identifier (e.g. en_GB) | string
# input        $aLanguageCode2s | array of languages identified by code2 | ref.array.string
# return       $aAttributes | list of attributes | ref.array.hash
#========================================================================================
sub csvAttributes {
    my $self = shift;
    my ($Shop, $LocaleID, $aLanguageCode2s) = @_;

    my $aAttributes = $self->SUPER::csvAttributes($Shop, $LocaleID, $aLanguageCode2s);

    #-- Columns exported by the super package
    #-- "Produkt [Product]";"Preisliste [PriceList]";"Menge [Quantity]";"Staffelpreis [Price]";"Mengenrabatt (%) [Discount]";"Wert [Value]";"Werterabatt (%) [ValueDiscount]"
    #--
    #-- This module is only used by NOW
    #-- In NOW, discount by value is not shown, so we need to exclude 'Value/'ValueDiscount'

    for(my $i = 0; $i < scalar(@$aAttributes); $i++) {
        if ( $aAttributes->[$i]->{'Alias'} eq 'Value' || $aAttributes->[$i]->{'Alias'} eq 'ValueDiscount' ) {
            splice(@$aAttributes, $i, 1);
            $i--;
        }
    }

    return $aAttributes
}

1;
