#========================================================================================
# package      DE_EPAGES::Product::API::Attributes::Class_Ext
# state        private
# base         DE_EPAGES::Product::API::BaseAttribute
# description  Implements calculated attributes
#========================================================================================
package DE_EPAGES::Product::API::Attributes::Class_Ext;
use base qw( DE_EPAGES::Object::API::BaseAttribute );

use strict;

#========================================================================================
# function     getAttributes
# state        private
# syntax       $Value = $Class->get($AttributeName);
#========================================================================================
sub getAttributes {
    shift;
    my ($Class, $aNames) = @_;

    my %Values;
    foreach my $Name (@$aNames) {
        if ($Name eq 'OwnUserDefinedAttributes') {
            $Values{$Name} = _OwnUserDefinedAttributes( $Class );
        }
        elsif ($Name eq 'InheritedUserDefinedAttributes') {
            $Values{$Name} = _InheritedUserDefinedAttributes( $Class );
        }
    }
    return \%Values;
}

# return own user defined atrtributes, order by Position
sub _OwnUserDefinedAttributes {
    my ($Class) = @_;

    my @Attributes;

    unshift @Attributes,
        sort { $a->get('Position') <=> $b->get('Position') }
        grep { $_->get('IsUserDefined') }
        @{ $Class->directAttributes };

    return \@Attributes;
}

# return inherited user defined atrtributes, order by BaseClass, Position
sub _InheritedUserDefinedAttributes {
    my ($Class) = @_;

    # do not return own attributes in case of the standard product type
    return [] if $Class->alias eq 'ProductClass';

    my @Attributes;
    $Class = $Class->get('BaseClass');
    while( defined $Class ) {
        unshift @Attributes,
            sort { $a->get('Position') <=> $b->get('Position') }
            grep { $_->get('IsUserDefined') }
            @{ $Class->directAttributes };
        $Class = $Class->get('BaseClass');
    }

    return \@Attributes;
}

1;
