#========================================================================================
# package      DE_EPAGES::Product::API::Attributes::Shop_Ext
# base         DE_EPAGES::Object::API::BaseAttribute
# state        private
# description  Implements calculated attributes
#========================================================================================
package DE_EPAGES::Product::API::Attributes::Shop_Ext;
use base DE_EPAGES::Object::API::BaseAttribute;
use strict;

use DE_EPAGES::Product::API::Table::ProductManufacturer qw( GetInfoProductManufacturersBySiteID );
use DE_EPAGES::ShopMailType::API::ShopMailType qw( GetShopMailType );


#========================================================================================
# function     getAttributes
# state        private
# syntax       $Value = $Object->get($AttributeName);
#========================================================================================
sub getAttributes {
    my $self = shift;
    my ($Object, $aNames) = @_;
    my $hInfo = {};
    foreach my $Name (@$aNames) {
        if ($Name eq 'ProductAvailabilityNotificationEmail') {
            my $MailType = GetShopMailType( $Object, 'ProductAvailibityNotification', 1 );
            $hInfo->{$Name} = defined $MailType ? 1 : 0;
        } elsif ($Name eq 'ManufacturerList') {
            $hInfo->{$Name} = _ManufacturerList($Object);
        }
    }
    return $hInfo;
}

sub _ManufacturerList {
    my ($Shop) = @_;

    return [sort { $a->{'Name'} cmp $b->{'Name'} } @{GetInfoProductManufacturersBySiteID($Shop->id)}];
}

#========================================================================================
# function     setAttributes
# state        private
# syntax       $Value = $Object->set($AttributeName, $Value);
#========================================================================================
sub setAttributes {
    shift;
    my ($Object, $hAttributes, $LanguageID) = @_;

    foreach my $Name (keys %$hAttributes) {
        my $value = $hAttributes->{$Name};
        if ($Name eq 'ProductAvailabilityNotificationEmail') {
            next unless defined $value;
            my $MailType = GetShopMailType( $Object, 'ProductAvailibityNotification' );
            $MailType->set({'IsActive'=>$value});
        }
    }
}

1;
