#========================================================================================
# §package      DE_EPAGES::Product::API::Resource::ProductFindResource
# §state        public
# §base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# §description  implements the REST resource to FIND a product via ep6
#               this is distinct from the search endpoint, which routes via epages-bloody-j :D
#========================================================================================
package DE_EPAGES::Product::API::Resource::ProductFindResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use JSON qw ( from_json );

use DE_EPAGES::Product::API::ProductService;
use DE_EPAGES::WebService::API::ResourcePager;
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Core::API::TestParameter qw ( TestString );
use DE_EPAGES::Database::API::Connection qw( GetCurrentDBHandle );

use strict;



sub service {
    return LoadObjectByPath('/RestServices/ProductFindResource');
}



sub class {
    return 'Shop';
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        POST => [
            [ 'post', 'application/vnd.epages.v1+json' ],
            [ 'post', 'application/json' ],
        ],
    }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/products/find$|;
    return 1;
}

sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if ($ActionName eq 'post') {
        return [ $Object, $Request ];
    }
    else {
        return [$Object];
    }
}

sub post {
    my $self = shift;
    my ( $Shop, $Request ) = @_;

    my $DecodedContent = $Request->decoded_content;
    my $hParams;
    eval {
        $hParams = from_json($DecodedContent);
    };
    die 'Invalid Body parameter' if $@ || ref $hParams ne 'HASH';

    my $AliasToSearchFor = $hParams->{'productNumber'};
    die 'productNumber is a required parameter' unless $AliasToSearchFor =~ /\S/;
    TestString('productNumber', $AliasToSearchFor);

    my $DBHandle = GetCurrentDBHandle();
    my $SearchSQL = 'select p.productid from product p join object o on p.productid=o.objectid where p.shopid=? and o.alias=?';

    my $aaResultSet = $DBHandle->execute( $SearchSQL, [$Shop->id, $AliasToSearchFor] );

    my $aFoundProducts = [];
    foreach my $aProductID (@$aaResultSet) {
        my $Product = $Shop->loadObject($aProductID->[0], 'Product');
        push @$aFoundProducts, $Product;
    }

    my $ProductService = $self->_createProductService();
    my $hShopData = $ProductService->getShopData($Shop, $Shop->get('LocaleID'), $Shop->get('CurrencyID'));
    my $Pager = DE_EPAGES::WebService::API::ResourcePager->new({
        'Page' => 1,
        'PageSize' => 100,
    });

    return $Pager->pagedItems($aFoundProducts, sub {
        $ProductService->getProductData($_[0], $hShopData, undef, undef);
    });
}

sub _createProductService {
    return DE_EPAGES::Product::API::ProductService->new();
}

1;
