#========================================================================================
# package      DE_EPAGES::Product::API::Resource::ProductSlideshowImageDeletion
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for deleting a slideshow image of a product.
#========================================================================================
package DE_EPAGES::Product::API::Resource::ProductSlideshowImageDeletion;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::Product::API::ProductImageService;
use DE_EPAGES::Product::API::ProductImageValidation;
use DE_EPAGES::Product::API::SlideshowService;

use strict;

sub service {
    return LoadObjectByPath('/RestServices/ProductSlideshowImageDeletion');
}

sub class {
    return 'Product';
}

sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        DELETE => [
            ['delete', undef],
        ],
    }->{$RequestMethod};
}

sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/products/([^/]+)/slideshow/([^/]+)/?$|;
    return [$1, $2];
}

sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request, $aPathParams) = @_;

    return [$Object, $aPathParams];
}

sub delete {
    my $self = shift;
    my ($Product, $aPathParams) = @_;

    my $ImageName = $aPathParams->[0];

    my $ProductImageService = $self->_createProductImageService($Product);
    $ProductImageService->deleteSlideShowImage($ImageName);

    return;
}

sub _createProductImageService {
    my $self = shift;
    my ($Product) = @_;
    return DE_EPAGES::Product::API::ProductImageService->new($Product);
}

1;
