#========================================================================================
# package      DE_EPAGES::Product::API::Resource::ProductTypeCollection
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for a single producttype.
#========================================================================================
package DE_EPAGES::Product::API::Resource::ProductType;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Object::API::Object::Locale;
use DE_EPAGES::Shop::API::Resource::Formatter;
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::WebService::API::ResourcePager;
use DE_EPAGES::Product::API::ProductTypeService;

use strict;

sub service {
    return LoadObjectByPath('/RestServices/ProductType');
}

sub class {
    return 'ProductType';
}

sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET  => [
            [ 'get', 'application/vnd.epages.v1+json' ],
            [ 'get', 'application/json' ],
        ],
        POST => [
            ['post', 'application/vnd.epages.v1+json'],
            ['post', 'application/json'],
        ],
        PATCH => [
            ['patch', 'application/vnd.epages.v1+json'],
            ['patch', 'application/json'],
        ],
    }->{$RequestMethod};
}

sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~m|^/api/producttypes/([^/]+)/?$|;

    return $1;
}

sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if( $ActionName eq 'get' ) {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        return [ $Object, $LocaleID];
    }
    elsif( $ActionName eq 'post' ) {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        return [ $Object, $LocaleID];
    }
    elsif( $ActionName eq 'patch' ) {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        return [ $Object, $LocaleID ];
    }
    else {
        return [$Object];
    }
}

sub hrefToProductType {
    my $self = shift;
    my ($APIBaseURL, $ProductTypeGUID) = @_;
    return "$APIBaseURL/api/producttypes/$ProductTypeGUID";

}
sub get {
    my $self = shift;
    my ($ProductType, $LocaleID) = @_;

    my $ProductTypeService = $self->_createProductTypeService;
    my $Shop = $ProductType->getSite();
    my $Context = $self->_createShopRequestContext($Shop);
    $LocaleID = $Context->validLocale($LocaleID);

    my $hProductType =  $ProductTypeService->getProductTypeData($ProductType, $LocaleID, $Shop);

    return $hProductType;
}

sub post {
    my $self = shift;
    my ($ProductType, $LocaleID, $hRequestBody) = @_;

    die 'Invalid Body parameter' if $@ || ref $hRequestBody ne 'HASH';
    die 'Invalid attributes value, must be array' if ref $hRequestBody->{'attributes'} ne 'ARRAY';

    my $Shop = $ProductType->getSite();
    my $Context = $self->_createShopRequestContext($Shop);
    $LocaleID = $Context->validLocale($LocaleID);

    my $ProductTypeService = $self->_createProductTypeService();
    return $ProductTypeService->createProductTypeAttributes($ProductType, $LocaleID, $hRequestBody);

}


sub patch {
    my $self = shift;
    my ($ProductType, $LocaleID, $ahRequestBody) = @_;

    my $ProductTypeService = $self->_createProductTypeService;
    my $Shop = $ProductType->getSite();
    my $Context = $self->_createShopRequestContext($Shop);
    $LocaleID = $Context->validLocale($LocaleID);
    $ProductTypeService->updateProductType($ProductType, $LocaleID, $ahRequestBody);

    return  $ProductTypeService->getProductTypeData($ProductType, $LocaleID, $Shop);
}

sub _createProductTypeService {
    return DE_EPAGES::Product::API::ProductTypeService->new();
}

sub _createShopRequestContext {
    my $self = shift;
    my ($Shop) = @_;
    return DE_EPAGES::Shop::API::Resource::ShopRequestContext->new($Shop);
}

1;
