#========================================================================================
# package      DE_EPAGES::Product::API::Resource::UpdatedProductsResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectCollectionResource
# description  implements the REST resource for the updated products collection.
#========================================================================================
package DE_EPAGES::Product::API::Resource::UpdatedProductsResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectCollectionResource;

use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Core::API::Object::DateTimeFormatter;
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Product::API::ProductService;
use DE_EPAGES::Product::API::Resource::Product;
use DE_EPAGES::WebService::API::ResourcePager;
use DE_EPAGES::XML::API::DateTimeFormatXML;
use DateTime;

use strict;



sub service {
    return LoadObjectByPath('/RestServices/UpdatedProductsResource');
}



sub class {
    return 'Shop';
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
    }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/updated-products/?$|;
    return 1;
}



sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if( $ActionName eq 'get' ) {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $ResultsPerPage = $hQuery->{'resultsPerPage'}->[0];
        my $Page = $hQuery->{'page'}->[0];
        my $LocaleID = $hQuery->{'locale'}->[0];
        my $CurrencyID = $hQuery->{'currency'}->[0];
        my $AttributesUpdatedSinceStr = $hQuery->{'attributesUpdatedSince'}->[0];
        my $StockLevelUpdatedSinceStr = $hQuery->{'stockLevelUpdatedSince'}->[0];
        my $AttributesUpdatedSince = $self->convertToDatetime($AttributesUpdatedSinceStr);
        my $StockLevelUpdatedSince = $self->convertToDatetime($StockLevelUpdatedSinceStr);

        return [ $Object, $ResultsPerPage, $Page, $LocaleID, $CurrencyID, $AttributesUpdatedSince, $StockLevelUpdatedSince];
    }
    else {
        return [ $Object ];
    }
}



sub get {
    my $self = shift;
    my ($Shop, $ResultsPerPage, $Page, $LocaleID, $CurrencyID, $AttributesUpdatedSince, $StockLevelUpdatedSince) = @_;

    my $Context = DE_EPAGES::Shop::API::Resource::ShopRequestContext->new($Shop);
    $LocaleID = $Context->validLocale($LocaleID);
    $CurrencyID = $Context->validCurrency($CurrencyID);

    my $ProductService = $self->_createProductService();
    my $aProducts = $ProductService->getAllUpdatedProducts($Shop, $AttributesUpdatedSince, $StockLevelUpdatedSince);

    my $Pager = DE_EPAGES::WebService::API::ResourcePager->new({
        'Page' => $Page,
        'PageSize' => $ResultsPerPage,
    });

    return $Pager->pagedItems($aProducts, sub {
        return {
            'item' => $ProductService->getProductDetailsData($Shop, $_->[0], $LocaleID, $CurrencyID),
            'lastUpdated' => $_->[1]
        }
    });
}



sub convertToDatetime {
    my $self = shift;
    my ($DateTimeString) = @_;

    if(!defined $DateTimeString) {
        return undef;
    }

    my $DateTimeFormatXML = DE_EPAGES::XML::API::DateTimeFormatXML->new();
    return $DateTimeFormatXML->parse_datetime( $DateTimeString, 'UTC' );
}



sub _createProductService {
    return DE_EPAGES::Product::API::ProductService->new();
}

1;
