#========================================================================================
# package      DE_EPAGES::Product::API::Resource::WatchedProductsResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectCollectionResource
# description  implements the REST resource for watched products.
#========================================================================================
package DE_EPAGES::Product::API::Resource::WatchedProductsResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectCollectionResource;

use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::Product::API::Resource::Product;
use DE_EPAGES::WebService::API::ResourcePager;
use DE_EPAGES::Product::API::WatchedProductsService;

use strict;



sub service {
    return LoadObjectByPath('/RestServices/WatchedProductsResource');
}



sub class {
    return 'Shop';
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
    }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/watched-products/?$|;
    return 1;
}



sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if( $ActionName eq 'get' ) {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        my $ResultsPerPage = $hQuery->{'resultsPerPage'}->[0];
        my $Page = $hQuery->{'page'}->[0];
        return [ $Object, $LocaleID, $ResultsPerPage, $Page ];
    }
    else {
        return [ $Object ];
    }
}



sub get {
    my $self = shift;
    my ($Shop, $LocaleID, $ResultsPerPage, $Page) = @_;

    my $Context = $self->_createShopRequestContext($Shop);
    $LocaleID = $Context->validLocale($LocaleID);

    my $Pager = DE_EPAGES::WebService::API::ResourcePager->new({
        'Page' => $Page,
        'PageSize' => $ResultsPerPage,
    });

    my $ShopId = $Shop->id();

    my $WatchedProductsService = $self->_createWatchedProductsService();

    my $hWatchedProducts = $WatchedProductsService->getNumberOfWatchersPerProduct($ShopId);
    my $aObjectIds = [keys(%$hWatchedProducts)];

    return $Pager->pagedItems($aObjectIds, sub {
        $WatchedProductsService->getWatchedProductDetails($Shop, $LocaleID, $_, $hWatchedProducts->{$_});
    });
}



sub _createWatchedProductsService {
    return DE_EPAGES::Product::API::WatchedProductsService->new();
}



sub _createShopRequestContext {
    my $self = shift;
    my ($Shop) = @_;
    return DE_EPAGES::Shop::API::Resource::ShopRequestContext->new($Shop);
}

1;
