#========================================================================================
# package      DE_EPAGES::Shipping::API::Resource::ShippingMethodCollection
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectCollectionResource
# description  implements the REST resource for the shipping method collection.
#========================================================================================
package DE_EPAGES::Shipping::API::Resource::ShippingMethodCollection;
use base DE_EPAGES::WebService::API::Resource::BaseObjectCollectionResource;

use strict;

use DE_EPAGES::Core::API::Url qw (ParseQueryString);
use DE_EPAGES::Object::API::Factory qw (LoadObjectByPath);
use DE_EPAGES::Shipping::API::Resource::ShippingMethod;

sub service {
    return LoadObjectByPath('/RestServices/ShippingMethodCollection');
}

sub class {
    return 'Shop';
}

sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
    }->{$RequestMethod};
}

sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/shipping-methods/?$|;
    return 1;
}

sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if ( $ActionName eq 'get' ) {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        return [ $Object, $LocaleID];
    } else {
        return [ $Object ];
    }
}

sub get {
    my $self = shift;
    my ($Shop, $LocaleID) = @_;


    my $ShippingMethodResource = DE_EPAGES::Shipping::API::Resource::ShippingMethod->new;
    return [
        map { $ShippingMethodResource->get($_, $LocaleID) }
        grep { $_->get('IsActivated') }
        @{$Shop->get('ShippingMethods')}
    ];
}

1;
