#========================================================================================
# package      DE_EPAGES::ShopNewsletter::API::Resource::CampaignCollectionResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  Resource for newsletter campaigns
#========================================================================================
package DE_EPAGES::ShopNewsletter::API::Resource::CampaignCollectionResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Object::API::Factory qw (LoadObjectByPath);
use DE_EPAGES::WebService::API::ResourcePager;
use DE_EPAGES::ShopNewsletter::API::NewsletterService;

use strict;



sub class {
    return 'Shop';
}



sub service {
    return LoadObjectByPath('/RestServices/CampaignCollection');
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
    }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;
    return unless $Request->uri->path =~ m|^/api/newsletter-campaigns/?$|;
    return 1;
}



sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if ($ActionName eq 'get') {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $ResultsPerPage = $hQuery->{'resultsPerPage'}->[0];
        my $Page = $hQuery->{'page'}->[0];
        return [ $Object, $ResultsPerPage, $Page ];
    } else {
        return [$Object];
    }
}



sub get {
    my $self = shift;
    my ( $Shop, $ResultsPerPage, $Page ) = @_;

    my $NewsletterService = $self->_createNewsletterService();
    my $aNewsletterCampaigns = $NewsletterService->getCampaigns($Shop);

    my $hPageOptions = {
        'Page' => $Page,
        'PageSize' => $ResultsPerPage,
    };
    my $Pager = $self->_createResourcePager($hPageOptions);

    return $Pager->pagedItems($aNewsletterCampaigns, sub {
        my $NewsletterCampaign = $_;
        $NewsletterService->getCampaignData($NewsletterCampaign);
    });
}



sub _createNewsletterService {
    my $self = shift;
    return DE_EPAGES::ShopNewsletter::API::NewsletterService->new();
}



sub _createResourcePager {
    my $self = shift;
    my ($hPageOptions) = @_;
    return DE_EPAGES::WebService::API::ResourcePager->new($hPageOptions);
}

1;
