#========================================================================================
# package      DE_EPAGES::ShopNewsletter::API::Resource::CampaignSubscribersCollectionResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  Resource for newsletter campaign subscribers
#========================================================================================
package DE_EPAGES::ShopNewsletter::API::Resource::CampaignSubscribersCollectionResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Object::API::Factory qw (LoadObjectByPath);
use DE_EPAGES::WebService::API::ResourcePager;
use DE_EPAGES::ShopNewsletter::API::NewsletterSubscriberService;

use strict;



sub class {
    return 'NewsletterCampaign';
}



sub service {
    return LoadObjectByPath('/RestServices/CampaignSubscribersCollection');
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
    }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;
    return unless $Request->uri->path =~ m|^/api/newsletter-campaigns/([^/]+)/subscribers/?$|;
    return $1;
}



sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if ($ActionName eq 'get') {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $ResultsPerPage = $hQuery->{'resultsPerPage'}->[0];
        my $Page = $hQuery->{'page'}->[0];
        return [ $Object, $ResultsPerPage, $Page ];
    } else {
        return [$Object];
    }
}



sub get {
    my $self = shift;
    my ( $NewsletterCampaign, $ResultsPerPage, $Page ) = @_;

    my $Shop = $NewsletterCampaign->getSite();
    my $NewsletterSubscriberService = $self->_createNewsletterSubscriberService();
    my $aSubscribedAddressees = $NewsletterSubscriberService->getCampaignSubscribers($NewsletterCampaign);

    my $hPageOptions = {
        'Page' => $Page,
        'PageSize' => $ResultsPerPage,
    };
    my $Pager = $self->_createResourcePager($hPageOptions);

    return $Pager->pagedItems($aSubscribedAddressees, sub {
        my $NewsletterAddressee = $_;
        $NewsletterSubscriberService->getNewsletterAddresseeData($Shop, $NewsletterAddressee);
    });
}



sub _createNewsletterSubscriberService {
    my $self = shift;
    return DE_EPAGES::ShopNewsletter::API::NewsletterSubscriberService->new();
}



sub _createResourcePager {
    my $self = shift;
    my ($hPageOptions) = @_;
    return DE_EPAGES::WebService::API::ResourcePager->new($hPageOptions);
}

1;
