#========================================================================================
# package      DE_EPAGES::ShopWizard::API::Attributes::StyleGroup
# state        private
# base         DE_EPAGES::Object::API::BaseAttribute
# description  Attribute interface for DemoContent.
#========================================================================================
package DE_EPAGES::ShopWizard::API::Attributes::StyleGroup;
use base qw( DE_EPAGES::Object::API::BaseAttribute );

use strict;

use DE_EPAGES::ShopWizard::API::XML::DemoContentImportHandler;
use DE_EPAGES::ShopWizard::API::XML::HashImportHandler qw ( ImportDemoContentData );
use DE_EPAGES::Trigger::API::Trigger qw (TriggerHook);

#========================================================================================
# function     getAttributes
# state        private
#----------------------------------------------------------------------------------------
# syntax       $hValues = $Package->( $Object, $aNames );
# example      # never call getAttributes directly!
#               $Value = $Object->get( $AttributeName );
#----------------------------------------------------------------------------------------
# description  Returns attribute values of an object.
#               Used by <function DE_EPAGES::Object::Object::Object::get>
#----------------------------------------------------------------------------------------
# input        $Object | object | object
# input        $aNames | list of attribute names | ref.array
# return       $hValues | attribute name => value hash | ref.hash
#========================================================================================
sub getAttributes {
    shift;
    my ($Object, $aNames, $LanguageID) = @_;
    my %Values;
    foreach my $Name ( @$aNames ) {
        if( $Name eq  'DemoContent' ) {
            $Values{$Name} = ImportDemoContentData($Object->get('DemoContentFiles', $LanguageID), undef, $LanguageID);
        }
        elsif( $Name eq  'DemoContentFiles' ) {
            # collect files from DemoContent cartridges
            my %Args = ('Files' => [] );
            TriggerHook('DemoContentFiles', \%Args);
            $Values{$Name} = [
                map { @{DE_EPAGES::ShopWizard::API::XML::DemoContentImportHandler->importXML($_, $Object->pathString)} }
                @{$Args{'Files'}}
            ];
        }
    }
    return \%Values;
}

1;
