#========================================================================================
# package      DE_EPAGES::Tax::API::Resource::TaxClassCollectionResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for listing tax classes.
#========================================================================================
package DE_EPAGES::Tax::API::Resource::TaxClassCollectionResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Object::API::Object::Locale;
use DE_EPAGES::Shop::API::Resource::Formatter;
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::WebService::API::ResourcePager;
use DE_EPAGES::Tax::API::TaxClassService;

use strict;



sub service {
    return LoadObjectByPath('/RestServices/TaxClassCollection');
}



sub class {
    return 'Shop';
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
    }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/tax-classes/?$|;
    return 1;
}



sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if ($ActionName eq 'get') {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        my $ResultsPerPage = $hQuery->{'resultsPerPage'}->[0];
        my $Page = $hQuery->{'page'}->[0];
        return [ $Object, $LocaleID, $ResultsPerPage, $Page ];
    } else {
        return [$Object];
    }
}



sub get {
    my $self = shift;
    my ($Shop, $LocaleID, $ResultsPerPage, $Page) = @_;

    my $Context = $self->_createShopRequestContext($Shop);
    $LocaleID = $Context->validLocale($LocaleID);

    my $hPageOptions = {
        'Page' => $Page,
        'PageSize' => $ResultsPerPage,
    };
    my $Pager = $self->_createResourcePager($hPageOptions);

    my $TaxClassService = $self->_createTaxClassService();
    my $aTaxClasses = $TaxClassService->getTaxClasses($Shop);


    my $TaxClassesPage = $Pager->pagedItems($aTaxClasses, sub {
        my $TaxClass = $_;
        $TaxClassService->getTaxClassData($TaxClass, $LocaleID);
    });

    my $DefaultTaxClasses = $TaxClassService->getDefaultTaxClasses($Shop);
    $TaxClassesPage->{'defaultTaxClass'} = $TaxClassService->getTaxClassData($DefaultTaxClasses->{'defaultTaxClass'}, $LocaleID);
    $TaxClassesPage->{'defaultTaxClassDigital'} = $TaxClassService->getTaxClassData($DefaultTaxClasses->{'defaultTaxClassDigital'}, $LocaleID);

    return $TaxClassesPage;
}



sub _createTaxClassService {
    return DE_EPAGES::Tax::API::TaxClassService->new();
}



sub _createResourcePager {
    my $self = shift;
    my ($hPageOptions) = @_;
    return DE_EPAGES::WebService::API::ResourcePager->new($hPageOptions);
}



sub _createShopRequestContext {
    my $self = shift;
    my ($Shop) = @_;
    return DE_EPAGES::Shop::API::Resource::ShopRequestContext->new($Shop);
}

1;
