#========================================================================================
# package      DE_EPAGES::Tax::API::Resource::TaxClassResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for tax class details
#========================================================================================
package DE_EPAGES::Tax::API::Resource::TaxClassResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Object::API::Object::Locale;
use DE_EPAGES::Shop::API::Resource::Formatter;
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::Shop::API::ShopTaxClass;
use DE_EPAGES::Tax::API::TaxClassService;

use strict;



sub service {
    return LoadObjectByPath('/RestServices/TaxClasses');
}



sub class {
    return 'Shop';
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
    }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/tax-classes/([^/]+)/?$|;

    return [1, $1];
}



sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request, $aPathParams) = @_;

    if ($ActionName eq 'get') {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        return [ $Object, $LocaleID, $aPathParams ];
    } else {
        return [$Object];
    }
}



sub get {
    my $self = shift;
    my ($Shop, $LocaleID, $aPathParams) = @_;

    my $TaxClassGUID = $aPathParams->[0];
    my $ShopTaxClass = $self->_createShopTaxClass($Shop);
    my $TaxClass = $ShopTaxClass->loadTaxClassbyGUID($TaxClassGUID);

    my $Context = $self->_createShopRequestContext($Shop);
    $LocaleID = $Context->validLocale($LocaleID);

    my $TaxClassService = $self->_createTaxClassService();
    my $hTaxClassData = $TaxClassService->getTaxClassData($TaxClass, $LocaleID);

    return $hTaxClassData;
}



sub _createTaxClassService {
    return DE_EPAGES::Tax::API::TaxClassService->new();
}



sub _createShopTaxClass {
    my $self = shift;
    my ($Shop) = @_;
    return DE_EPAGES::Shop::API::ShopTaxClass->new($Shop);
}



sub _createShopRequestContext {
    my $self = shift;
    my ($Shop) = @_;
    return DE_EPAGES::Shop::API::Resource::ShopRequestContext->new($Shop);
}

1;
