#========================================================================================
# package      DE_EPAGES::TrustedShops::API::Attributes::TrustedShopsCertificate
# state        private
# description  Attribute interface for trusted shops TrustedShopsCertificate.
#========================================================================================
package DE_EPAGES::TrustedShops::API::Attributes::TrustedShopsCertificate;
use base DE_EPAGES::Object::API::BaseAttribute;
use DE_EPAGES::TrustedShops::API::Constants qw (%CERT_STATUS);

use strict;

#========================================================================================
sub getAttributes {
    my $self = shift;
    my ($Shop, $aNames) = @_;
    my $hInfo = {};

    foreach my $Name ( @$aNames ) {
        if ($Name eq 'ProtectionItems'){
            $hInfo->{$Name} = $self->_getProtectionItems($Shop);
        }
        elsif ($Name eq 'CertificateStatusText'){
            $hInfo->{$Name} = $self->_getCertificateStatusText($Shop);
        }
    }

    return $hInfo;
}
sub _getProtectionItems {
    shift;
    my ($Shop) = @_;
    my $ProtectionItem = [];
    if ($Shop->existsChild('ProtectionItems')) {
        $ProtectionItem = [sort { $a->get('ProtectedAmount') <=> $b->get('ProtectedAmount') } @{$Shop->child('ProtectionItems')->children}];
    }
    return $ProtectionItem;
}
sub _getCertificateStatusText {
    shift;
    my ($Shop) = @_;
    my $CertificateStatus = $Shop->get('CertificateStatus');
        return 'UNKNOWN' unless defined $CertificateStatus;
    my $StatusText;

    if($CertificateStatus eq $CERT_STATUS{'PRODUCTION'}) {$StatusText  = 'Live'}
    elsif($CertificateStatus eq $CERT_STATUS{'TEST'}) {$StatusText  = 'Test'}
    elsif($CertificateStatus eq $CERT_STATUS{'INVALID_TS_ID'}) {$StatusText  = 'INVALID'}
    elsif($CertificateStatus eq $CERT_STATUS{'CANCELLED'}) {$StatusText  = 'CANCELLED'}
    elsif($CertificateStatus eq $CERT_STATUS{'DISABLED'}) {$StatusText  = 'DISABLED'}
    elsif($CertificateStatus eq $CERT_STATUS{'INTEGRATION'}) {$StatusText  = 'INTEGRATION'}
    else {$StatusText  = 'OTHER'}

    return $StatusText;
}
#========================================================================================
sub deleteObject {
    shift;
    my ($Object) = @_;
    $Object->child('ProtectionItems')->delete if $Object->existsChild('ProtectionItems');
}

1;
