#========================================================================================
# package      DE_EPAGES::USPS::UI::ShippingTransactionUSPS
# base         DE_EPAGES::ExternalShipping::UI::ShippingTransaction
# state        public
# description  Description
#========================================================================================
package DE_EPAGES::USPS::UI::ShippingTransactionUSPS;
use base DE_EPAGES::ExternalShipping::UI::ShippingTransaction;
use DE_EPAGES::USPS::API::ShippingOrder;

use strict;

#========================================================================================
# function     SendShippingOrderHelper
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Handler->SendShippingOrderHelper( $Servlet );
#----------------------------------------------------------------------------------------
# description  overwrite SendShippingOrderHelper from ShippingTransaction of external shipping
#               trigger the Webservice of USPS
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet | object
#========================================================================================
sub SendShippingOrderHelper {
    my $self = shift;
    my ($Servlet) = @_;

    # checks if all selected shipping labels are valid. It throws an error/warning otherwise
    $self->ValidateShippingOrder($Servlet);

    my $Transaction = $Servlet->object;
    my $ShippingFulfillmentMethod = $Transaction->get('ShippingFulfillmentMethod');
    my $ShippingOrder = DE_EPAGES::USPS::API::ShippingOrder->new($ShippingFulfillmentMethod);
    $ShippingOrder->trigger($Transaction);
    $self->_transactionErrorHandling($Servlet);

    return undef;
}

#========================================================================================
# function     _transactionErrorHandling
# state        private
#----------------------------------------------------------------------------------------
# syntax       _transactionErrorHandling( $Servlet );
#----------------------------------------------------------------------------------------
# description  depending on the the TransStatus of the transaction it will choose the correct
#               viewaction and, if needed, Error handling
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet | object
#========================================================================================
sub _transactionErrorHandling {
    my $self = shift;
    my ($Servlet) = @_;

    my $Transaction = $Servlet->object;
    my $TransStatus = $Transaction->get('TransStatus');
    if ($TransStatus eq 'AllShippingLabelsProceeded') {
        $self->_changeViewActionToTransactionDetailView($Servlet);
    }
    elsif ($TransStatus eq 'SomeShippingLabelsProceeded') {
        $self->_changeViewActionAndErrorMessageForTransactionDetailView($Servlet);
    }
    elsif ($TransStatus eq 'NoShippingLabelsProceeded') {
        $self->_changeViewActionAndErrorMessageForShippingOrderView($Servlet);
    }

    return undef;
}

#========================================================================================
# function     _changeViewActionToTransactionDetailView
# state        private
#----------------------------------------------------------------------------------------
# syntax       _changeViewActionToTransactionDetailView( $Servlet );
#----------------------------------------------------------------------------------------
# description  change the viewaction
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet | object
#========================================================================================
sub _changeViewActionToTransactionDetailView {
    my $self = shift;
    my ($Servlet) = @_;

    $Servlet->vars( 'ViewAction',  'MBO-ViewGeneral' );

    return undef;
}

#========================================================================================
# function     _changeViewActionAndErrorMessageForTransactionDetailView
# state        private
#----------------------------------------------------------------------------------------
# syntax       _changeViewActionAndErrorMessageForTransactionDetailView( $Servlet );
#----------------------------------------------------------------------------------------
# description  change the viewaction
#               change the objectID
#               add error message
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet | object
#========================================================================================
sub _changeViewActionAndErrorMessageForTransactionDetailView {
    my $self = shift;
    my ($Servlet) = @_;

    $Servlet->vars( 'BatchActionError', 'SomeShippingLabelsProceeded' );
    my $ShopObjectID = $Servlet->object()->getSite()->id();
    my $ViewAction = 'MBO-ViewUSPSShippingOrder';
    $Servlet->vars( 'LinkToShippingOrders', '?ViewAction='.$ViewAction.'&amp;ObjectID='.$ShopObjectID );
    $self->_changeViewActionToTransactionDetailView($Servlet);

    return undef;
}

#========================================================================================
# function     _changeViewActionAndErrorMessageForShippingOrderView
# state        private
#----------------------------------------------------------------------------------------
# syntax       _changeViewActionAndErrorMessageForShippingOrderView( $Servlet );
#----------------------------------------------------------------------------------------
# description  change the viewaction
#               change the objectID
#               add error message
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet | object
#========================================================================================
sub _changeViewActionAndErrorMessageForShippingOrderView {
    my $self = shift;
    my ($Servlet) = @_;

    $Servlet->vars( 'ViewAction', 'MBO-ViewUSPSShippingOrder' );
    $Servlet->vars( 'ObjectID',$Servlet->object()->getSite()->id() );
    $Servlet->vars( 'BatchActionError', 'NoShippingLabelsProceeded' );

    return undef;
}

1;
